"""
The name list was sourced from UCD and DCU project
 https://www.duchas.ie/en/nom

first names from Northern Ireland Statistics and Research Agency
 https://www.nisra.gov.uk/publications/baby-names-2016
1996 series
"""

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}-{{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}-{{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
    )
    first_names_male = (
        "Aaron",
        "Adam",
        "Adrian",
        "Aedan",
        "Aidan",
        "Aiden",
        "Alan",
        "Alastair",
        "Albert",
        "Alex",
        "Alexander",
        "Alistair",
        "Alister",
        "Andrew",
        "Angus",
        "Anthony",
        "Antoin",
        "Anton",
        "Aodhan",
        "Arran",
        "Arron",
        "Ashley",
        "Bailey",
        "Bailie",
        "Barry",
        "Ben",
        "Benjamin",
        "Benn",
        "Bernard",
        "Blaine",
        "Blake",
        "Brad",
        "Bradley",
        "Brandon",
        "Breandan",
        "Brendan",
        "Brett",
        "Brian",
        "Bryan",
        "Cahal",
        "Cahir",
        "Cailum",
        "Cal",
        "Caleb",
        "Callan",
        "Callum",
        "Calum",
        "Calvin",
        "Cameron",
        "Caoimhin",
        "Caolain",
        "Caolan",
        "Caomhan",
        "Carl",
        "Carter",
        "Cathal",
        "Charles",
        "Charlie",
        "Che",
        "Chris",
        "Christian",
        "Christie",
        "Christopher",
        "Christy",
        "Cianan",
        "Ciaran",
        "Cillian",
        "Clark",
        "Clifford",
        "Cody",
        "Colin",
        "Colm",
        "Colum",
        "Conal",
        "Conall",
        "Conan",
        "Conchur",
        "Conn",
        "Connor",
        "Conor",
        "Conrad",
        "Corey",
        "Cormac",
        "Cory",
        "Craig",
        "Curtis",
        "Daire",
        "Dale",
        "Damian",
        "Damien",
        "Daniel",
        "Danny",
        "Dara",
        "Darragh",
        "Darrell",
        "Darren",
        "Darryl",
        "Daryl",
        "David",
        "Deaglan",
        "Dean",
        "Deane",
        "Declan",
        "Dennis",
        "Dermot",
        "Desmond",
        "Diarmuid",
        "Dillon",
        "Domhnall",
        "Dominic",
        "Don",
        "Donal",
        "Duncan",
        "Dylan",
        "Eamon",
        "Eamonn",
        "Edward",
        "Elliot",
        "Emmet",
        "Emmett",
        "Enda",
        "Eoghan",
        "Eoin",
        "Eric",
        "Ethan",
        "Euan",
        "Eugene",
        "Eunan",
        "Evan",
        "Ewan",
        "Feargal",
        "Fearghal",
        "Fergal",
        "Fergus",
        "Finbar",
        "Finn",
        "Fintan",
        "Fionntan",
        "Francis",
        "Frazer",
        "Gabriel",
        "Gareth",
        "Garrett",
        "Gary",
        "Gavin",
        "Geoffrey",
        "George",
        "Gerald",
        "Gerard",
        "Giles",
        "Glen",
        "Glenn",
        "Gordon",
        "Graeme",
        "Graham",
        "Grant",
        "Gregory",
        "Hamish",
        "Harry",
        "Harvey",
        "Hayden",
        "Henry",
        "Hugh",
        "Iain",
        "Ian",
        "Isaac",
        "Jack",
        "Jackson",
        "Jacob",
        "Jaime",
        "Jake",
        "James",
        "Jamie",
        "Jared",
        "Jarlath",
        "Jason",
        "Jay",
        "Jeffrey",
        "Jesse",
        "Joe",
        "Joel",
        "John",
        "Johnathan",
        "Johnny",
        "Jon",
        "Jonathan",
        "Jonathon",
        "Jordan",
        "Jordon",
        "Joseph",
        "Josh",
        "Joshua",
        "Jude",
        "Justin",
        "Kane",
        "Karl",
        "Kealan",
        "Keelan",
        "Keith",
        "Kelvin",
        "Kenneth",
        "Kevin",
        "Kieran",
        "Killian",
        "Kirk",
        "Kristian",
        "Kristopher",
        "Kurt",
        "Kurtis",
        "Kyle",
        "Lee",
        "Leo",
        "Leon",
        "Lewis",
        "Liam",
        "Lloyd",
        "Logan",
        "Lorcan",
        "Louis",
        "Lucas",
        "Luke",
        "Lyndon",
        "Macauley",
        "Mairtin",
        "Malachy",
        "Malcolm",
        "Manus",
        "Marc",
        "Marco",
        "Marcus",
        "Mark",
        "Martin",
        "Matthew",
        "Max",
        "Michael",
        "Micheal",
        "Mitchel",
        "Mitchell",
        "Morgan",
        "Myles",
        "Naoise",
        "Nathan",
        "Nathaniel",
        "Neil",
        "Niall",
        "Nicholas",
        "Nigel",
        "Noel",
        "Odhran",
        "Oisin",
        "Oliver",
        "Omar",
        "Oran",
        "Owen",
        "Padraic",
        "Padraig",
        "Patrick",
        "Paul",
        "Pauric",
        "Peadar",
        "Pearce",
        "Pearse",
        "Peter",
        "Philip",
        "Phillip",
        "Piaras",
        "Pierce",
        "Raymond",
        "Reece",
        "Reuben",
        "Rhys",
        "Rian",
        "Richard",
        "Robbie",
        "Robert",
        "Robin",
        "Rohan",
        "Ronan",
        "Rory",
        "Ross",
        "Rowan",
        "Roy",
        "Ruairi",
        "Ruari",
        "Russell",
        "Ryan",
        "Sam",
        "Samuel",
        "Saul",
        "Scot",
        "Scott",
        "Seamus",
        "Sean",
        "Sean-Paul",
        "Shane",
        "Shaun",
        "Shay",
        "Shea",
        "Simon",
        "Stefan",
        "Stephen",
        "Steven",
        "Stewart",
        "Stuart",
        "Taylor",
        "Terence",
        "Thomas",
        "Tiarnan",
        "Tiernan",
        "Timothy",
        "Tobias",
        "Toby",
        "Tom",
        "Tomas",
        "Tony",
        "Travis",
        "Trevor",
        "Tristan",
        "Troy",
        "Tyler",
        "Tyrone",
        "Vincent",
        "Warren",
        "Wayne",
        "William",
        "Zac",
        "Zach",
        "Zachary",
        "Zak",
    )

    first_names_female = (
        "Abbi",
        "Abbie",
        "Abby",
        "Abigail",
        "Adele",
        "Aideen",
        "Aileen",
        "Ailis",
        "Aimee",
        "Aine",
        "Aisling",
        "Aislinn",
        "Alana",
        "Alanis",
        "Alanna",
        "Alannah",
        "Alex",
        "Alexandra",
        "Alexandria",
        "Alice",
        "Alicia",
        "Alisha",
        "Alison",
        "Alix",
        "Amanda",
        "Amber",
        "Amelia",
        "Amie",
        "Amy",
        "Amy-Lee",
        "Amy-Leigh",
        "Anastasia",
        "Andrea",
        "Angela",
        "Anna",
        "Annalise",
        "Anne-Marie",
        "Annie",
        "Antoinette",
        "Aoibheann",
        "Aoibhin",
        "Aoibhinn",
        "Aoife",
        "April",
        "Arianne",
        "Ashleigh",
        "Ashlene",
        "Ashley",
        "Ashling",
        "Ashton",
        "Ayesha",
        "Bernadette",
        "Beth",
        "Bethan",
        "Bethany",
        "Billie-Jo",
        "Blanaid",
        "Brigid",
        "Brittany",
        "Brogan",
        "Bronach",
        "Bronagh",
        "Brooke",
        "Brooklyn",
        "Bryony",
        "Cailin",
        "Caitlin",
        "Caitlyn",
        "Caitriona",
        "Caoilfhionn",
        "Caoimhe",
        "Cara",
        "Caragh",
        "Carla",
        "Carly",
        "Carmel",
        "Carol",
        "Caroline",
        "Carolyn",
        "Carrie",
        "Casey",
        "Cassandra",
        "Cassie",
        "Catherine",
        "Cathy",
        "Catriona",
        "Ceara",
        "Celine",
        "Chantel",
        "Chantelle",
        "Charis",
        "Charlene",
        "Charlie",
        "Charlotte",
        "Chelsea",
        "Chelsey",
        "Cherie",
        "Cherith",
        "Chloe",
        "Christina",
        "Christine",
        "Ciara",
        "Ciarrai",
        "Claire",
        "Clara",
        "Clare",
        "Clarissa",
        "Claudia",
        "Cliodhna",
        "Cliona",
        "Clodagh",
        "Codie",
        "Colleen",
        "Collette",
        "Connie",
        "Constance",
        "Cora",
        "Corinne",
        "Corrie",
        "Cortney",
        "Courteney",
        "Courtney",
        "Daire",
        "Dairine",
        "Dana",
        "Danielle",
        "Dara",
        "Darcy",
        "Darragh",
        "Dawn",
        "Dayna",
        "Dearbhail",
        "Dearbhaile",
        "Dearbhla",
        "Deborah",
        "Deirbhile",
        "Demi",
        "Demi-Lee",
        "Demi-Leigh",
        "Denise",
        "Dervla",
        "Diane",
        "Dionne",
        "Donna",
        "Eadaoin",
        "Ebony",
        "Edel",
        "Eden",
        "Eileen",
        "Eilis",
        "Eilish",
        "Eimear",
        "Eimer",
        "Eimhear",
        "Elaine",
        "Eleanor",
        "Elise",
        "Elisha",
        "Elizabeth",
        "Ella",
        "Ellen",
        "Ellie",
        "Eloise",
        "Emer",
        "Emilie",
        "Emily",
        "Emma",
        "Emma-Louise",
        "Enya",
        "Erica",
        "Erika",
        "Erin",
        "Eryn",
        "Esther",
        "Eva",
        "Eve",
        "Evelyn",
        "Evie",
        "Fainche",
        "Faith",
        "Faye",
        "Fiona",
        "Fionnuala",
        "Frances",
        "Francesca",
        "Freya",
        "Gabrielle",
        "Gemma",
        "Georgia",
        "Georgina",
        "Geraldine",
        "Gillian",
        "Gina",
        "Grace",
        "Grainne",
        "Haley",
        "Hannah",
        "Harriet",
        "Hayleigh",
        "Hayley",
        "Heather",
        "Heidi",
        "Helen",
        "Helena",
        "Hollie",
        "Holly",
        "India",
        "Iona",
        "Jacqueline",
        "Jade",
        "Jamie",
        "Jamie-Lee",
        "Jamie-Leigh",
        "Jana",
        "Jane",
        "Janet",
        "Janice",
        "Janine",
        "Jasmin",
        "Jasmine",
        "Jayde",
        "Jayne",
        "Jemma",
        "Jena",
        "Jenna",
        "Jenni",
        "Jennifer",
        "Jenny",
        "Jessica",
        "Jill",
        "Joanna",
        "Joanne",
        "Jodie",
        "Jody",
        "Johanna",
        "Jolene",
        "Jordan",
        "Josephine",
        "Joy",
        "Judith",
        "Julia",
        "Julie",
        "Julie-Anne",
        "Justine",
        "Kaitlin",
        "Kaitlyn",
        "Kara",
        "Karen",
        "Karla",
        "Karley",
        "Kate",
        "Katelyn",
        "Katharine",
        "Katherine",
        "Kathleen",
        "Kathryn",
        "Kathy",
        "Katie",
        "Katie-Louise",
        "Katrina",
        "Katy",
        "Kayleigh",
        "Keely",
        "Keeva",
        "Kellie",
        "Kelly",
        "Kelly-Anne",
        "Kelly-Marie",
        "Kelsey",
        "Keri",
        "Kerri",
        "Kerrie",
        "Kerry",
        "Kiera",
        "Kimberly",
        "Kira",
        "Kirby",
        "Kirsten",
        "Kirstie",
        "Kirstin",
        "Kirsty",
        "Kori",
        "Kristin",
        "Kristina",
        "Lana",
        "Laoise",
        "Lara",
        "Laura",
        "Lauren",
        "Laurie",
        "Leah",
        "Leanne",
        "Leigh",
        "Leona",
        "Leonie",
        "Lesley",
        "Lindsay",
        "Lisa",
        "Lisa-Marie",
        "Lois",
        "Lorna",
        "Louise",
        "Lucia",
        "Lucinda",
        "Lucy",
        "Lydia",
        "Lynda",
        "Lyndsay",
        "Lyndsey",
        "Lynsey",
        "Madison",
        "Maeve",
        "Mairead",
        "Margaret",
        "Maria",
        "Marie",
        "Marie-Claire",
        "Martha",
        "Martina",
        "Mary",
        "Maura",
        "Maureen",
        "Meabh",
        "Meaghan",
        "Meg",
        "Megan",
        "Meghan",
        "Meibh",
        "Melanie",
        "Melissa",
        "Mia",
        "Michaela",
        "Micheala",
        "Michelle",
        "Miriam",
        "Mollie",
        "Molly",
        "Morgan",
        "Nadia",
        "Nadine",
        "Naoimh",
        "Naoise",
        "Naomh",
        "Naomi",
        "Natalie",
        "Natasha",
        "Niamh",
        "Nichola",
        "Nichole",
        "Nicola",
        "Nicole",
        "Nikita",
        "Nikki",
        "Nina",
        "Nora",
        "Nuala",
        "Olivia",
        "Oonagh",
        "Orfhlaith",
        "Orla",
        "Orlagh",
        "Orlaigh",
        "Orlaith",
        "Padraigin",
        "Paige",
        "Patrice",
        "Patricia",
        "Paula",
        "Phoebe",
        "Polly",
        "Rachael",
        "Rachel",
        "Rachelle",
        "Rebecca",
        "Rebekah",
        "Regan",
        "Rhian",
        "Rhianna",
        "Rhianne",
        "Rhiannon",
        "Roberta",
        "Robyn",
        "Roise",
        "Roisin",
        "Rose",
        "Roseanna",
        "Rosemary",
        "Rosie",
        "Ruth",
        "Sabrina",
        "Sacha",
        "Samantha",
        "Sandra",
        "Saoirse",
        "Sara",
        "Sarah",
        "Sarah-Jane",
        "Sarah-Louise",
        "Sasha",
        "Saskia",
        "Savannah",
        "Seana",
        "Seanan",
        "Seaneen",
        "Seanna",
        "Selina",
        "Seona",
        "Serena",
        "Shania",
        "Shanice",
        "Shanna",
        "Shannan",
        "Shannen",
        "Shannon",
        "Sharon",
        "Shauna",
        "Shauneen",
        "Shelby",
        "Shelley",
        "Sheree",
        "Shona",
        "Sian",
        "Simone",
        "Sinead",
        "Siobhan",
        "Siofra",
        "Sophia",
        "Sophie",
        "Sophie-Louise",
        "Sorcha",
        "Stacey",
        "Stephanie",
        "Susan",
        "Susanna",
        "Susannah",
        "Suzanne",
        "Tamara",
        "Tammy",
        "Tanya",
        "Tara",
        "Taylor",
        "Teresa",
        "Terri",
        "Tess",
        "Tessa",
        "Theresa",
        "Therese",
        "Tia",
        "Tiarna",
        "Tiegan",
        "Tiffany",
        "Toni",
        "Tonicha",
        "Tori",
        "Tory",
        "Tracey",
        "Tyler",
        "Una",
        "Ursula",
        "Vanessa",
        "Victoria",
        "Whitney",
        "Yasmin",
        "Yasmine",
        "Zara",
        "Zoe",
    )

    first_names = first_names_male + first_names_female

    last_names = (
        "Achison",
        "Adams",
        "Agnew",
        "Ahearn",
        "Ahearne",
        "Ahern",
        "Aherne",
        "Ainsboro",
        "Allen",
        "Allis",
        "Anderson",
        "Andrews",
        "Angus",
        "Annsboro",
        "Ansboro",
        "Arthurs",
        "Ashe",
        "Ashman",
        "Atchison",
        "Atkins",
        "Atkinson",
        "Aylward",
        "Baker",
        "Baldwin",
        "Bale",
        "Bandeville",
        "Banks",
        "Bann",
        "Bannon",
        "Banville",
        "Barnes",
        "Barnett",
        "Barneville",
        "Barrett",
        "Barrnette",
        "Barron",
        "Barry",
        "Bartley",
        "Bates",
        "Baxter",
        "Beakey",
        "Beal",
        "Beale",
        "Beasty",
        "Beattie",
        "Beatty",
        "Beggan",
        "Beggs",
        "Begley",
        "Behan",
        "Beirn",
        "Beirne",
        "Bell",
        "Belton",
        "Bennet",
        "Bennett",
        "Beresford",
        "Bergin",
        "Bermingham",
        "Berminghim",
        "Bernard",
        "Berney",
        "Bernie",
        "Berry",
        "Biesty",
        "Bird",
        "Birmingham",
        "Bishop",
        "Black",
        "Blake",
        "Blanch",
        "Blanche",
        "Bodkin",
        "Bogan",
        "Bohan",
        "Boland",
        "Boles",
        "Bolger",
        "Bonar",
        "Boner",
        "Bones",
        "Bonner",
        "Boreland",
        "Borland",
        "Bourke",
        "Bowe",
        "Bowen",
        "Bowler",
        "Bowles",
        "Boyce",
        "Boylan",
        "Boyle",
        "Boyse",
        "Bradden",
        "Bradley",
        "Brady",
        "Branaola",
        "Brannelly",
        "Brassil",
        "Bray",
        "Bree",
        "Breen",
        "Breheny",
        "Brennan",
        "Breslin",
        "Bresnehan",
        "Brett",
        "Brick",
        "Bridge",
        "Bridson",
        "Brien",
        "Briody",
        "Brislane",
        "Broderick",
        "Brody",
        "Brogan",
        "Brophy",
        "Brosnan",
        "Brown",
        "Browne",
        "Broy",
        "Bruen",
        "Bruton",
        "Bryan",
        "Bryson",
        "Buckley",
        "Burchill",
        "Burke",
        "Burns",
        "Burton",
        "Butler",
        "Buttimer",
        "Buttimore",
        "Byrne",
        "Byrnes",
        "Cadden",
        "Caddow",
        "Cadogan",
        "Cafferkey",
        "Cafferky",
        "Cafferty",
        "Caffrey",
        "Cagney",
        "Cahalane",
        "Cahill",
        "Cahillane",
        "Cahir",
        "Caine",
        "Cairn",
        "Cairns",
        "Caldwell",
        "Callaghan",
        "Callan",
        "Callanan",
        "Calligan",
        "Callinan",
        "Cally",
        "Calvey",
        "Campbell",
        "Canavan",
        "Cannan",
        "Canniffe",
        "Canning",
        "Cannon",
        "Canny",
        "Cantwell",
        "Caplis",
        "Capples",
        "Capua",
        "Carbery",
        "Carey",
        "Carleton",
        "Carley",
        "Carlin",
        "Carmody",
        "Carney",
        "Carolan",
        "Carr",
        "Carragher",
        "Carrig",
        "Carrigan",
        "Carrigy",
        "Carroll",
        "Carry",
        "Carter",
        "Carthy",
        "Carton",
        "Carty",
        "Carville",
        "Casey",
        "Cashen",
        "Cashman",
        "Cassen",
        "Casserley",
        "Casserly",
        "Cassidy",
        "Cassin",
        "Cattigan",
        "Cauley",
        "Caulfield",
        "Cavanagh",
        "Cawley",
        "Charles",
        "Christopher",
        "Clafferty",
        "Claffey",
        "Clair",
        "Clancy",
        "Clare",
        "Clarke",
        "Classon",
        "Clavin",
        "Clear",
        "Cleary",
        "Clements",
        "Clenaghan",
        "Clerkin",
        "Clery",
        "Clifford",
        "Clinten",
        "Clinton",
        "Clogherty",
        "Cloherty",
        "Clohessey",
        "Clohessy",
        "Cloney",
        "Cloonan",
        "Cloone",
        "Clooney",
        "Clune",
        "Coady",
        "Coakley",
        "Cody",
        "Coen",
        "Coffey",
        "Cogan",
        "Cogley",
        "Cohalan",
        "Cohen",
        "Coholan",
        "Cole",
        "Coleman",
        "Colfer",
        "Colgan",
        "Colhoun",
        "Coll",
        "Collen",
        "Colleneler",
        "Colleran",
        "Colley",
        "Collier",
        "Colligan",
        "Collinder",
        "Collins",
        "Colly",
        "Colreavy",
        "Colum",
        "Comber",
        "Combre",
        "Comer",
        "Comerford",
        "Comisky",
        "Commins",
        "Comyn",
        "Conaty",
        "Conboy",
        "Concannon",
        "Condon",
        "Condren",
        "Condron",
        "Conefrey",
        "Conlan",
        "Conlon",
        "Conmee",
        "Conmy",
        "Connachton",
        "Connaghy",
        "Connaughton",
        "Conneeley",
        "Conneely",
        "Connell",
        "Connellan",
        "Connelly",
        "Connery",
        "Connole",
        "Connolly",
        "Connor",
        "Connors",
        "Conole",
        "Conree",
        "Conroy",
        "Conry",
        "Considine",
        "Convey",
        "Conway",
        "Conwell",
        "Coogan",
        "Cook",
        "Cooke",
        "Coolahan",
        "Coonan",
        "Cooney",
        "Corbett",
        "Corcoran",
        "Corduff",
        "Corish",
        "Corkery",
        "Corless",
        "Corley",
        "Cormack",
        "Cormican",
        "Cormick",
        "Cormy",
        "Corr",
        "Corridan",
        "Corrigan",
        "Corry",
        "Cosgrave",
        "Cosgrove",
        "Costello",
        "Costelloe",
        "Costigan",
        "Cotter",
        "Coughlan",
        "Counihan",
        "Courcey",
        "Cournane",
        "Courtenay",
        "Courtney",
        "Cousins",
        "Cowan",
        "Cowely",
        "Cowen",
        "Cowley",
        "Cox",
        "Coyle",
        "Coyne",
        "Crahan",
        "Craig",
        "Craine",
        "Crampsey",
        "Crampsie",
        "Crane",
        "Crangle",
        "Cranley",
        "Cranly",
        "Craven",
        "Crawley",
        "Crean",
        "Creed",
        "Creedon",
        "Cregan",
        "Crehan",
        "Cremin",
        "Cribbons",
        "Crilly",
        "Crimmins",
        "Crinion",
        "Croal",
        "Crohan",
        "Crolly",
        "Cronelly",
        "Cronin",
        "Cronly",
        "Crosbie",
        "Crosby",
        "Cross",
        "Crossan",
        "Crota",
        "Crotty",
        "Crowe",
        "Crowley",
        "Crudden",
        "Cruise",
        "Cryan",
        "Cuddihy",
        "Cuffe",
        "Culhane",
        "Cullen",
        "Culligan",
        "Cullinan",
        "Cullinane",
        "Culloty",
        "Cully",
        "Cumiskey",
        "Cumisky",
        "Cummins",
        "Cummiskey",
        "Cummisky",
        "Cunnane",
        "Cunneen",
        "Cunningham",
        "Cunny",
        "Curley",
        "Curnane",
        "Curneen",
        "Curnyn",
        "Curran",
        "Currie",
        "Curry",
        "Curtin",
        "Curtis",
        "Cusack",
        "D'Arcy",
        "Daiken",
        "Dalton",
        "Daly",
        "Danaher",
        "Dane",
        "Daniel",
        "Daniels",
        "Darcy",
        "Dargan",
        "Darmody",
        "Dasey",
        "Davenport",
        "Davern",
        "Davey",
        "Davin",
        "Davis",
        "Davitt",
        "Davoren",
        "Davy",
        "Daw",
        "Dawson",
        "Day",
        "Deacon",
        "Deacy",
        "Deady",
        "Dean",
        "Deane",
        "Dease",
        "Deasy",
        "Dee",
        "Deegadan",
        "Deegan",
        "Deehan",
        "Deeley",
        "Deely",
        "Deeney",
        "Deeny",
        "Deere",
        "Deery",
        "Deigan",
        "Deignan",
        "Delahunty",
        "Delaney",
        "Delap",
        "Delargy",
        "Deloughrey",
        "Deloughry",
        "Dempsey",
        "Denihan",
        "Denis",
        "Denison",
        "Dennehy",
        "Denning",
        "Denny",
        "Dermody",
        "Dermott",
        "Derrig",
        "Desmond",
        "Devally",
        "Devane",
        "Devaney",
        "Devanney",
        "Devenney",
        "Dever",
        "Devereaux Deaueroux",
        "Devereux",
        "Devery",
        "Devilly",
        "Devin",
        "Devine",
        "Devitt",
        "Devlin",
        "Devoy",
        "Dickey",
        "Dickie",
        "Dickson",
        "Diffin",
        "Diffley",
        "Diggin",
        "Diggins",
        "Dignan",
        "Dillane",
        "Dillon",
        "Dinan",
        "Dineen",
        "Dinneen",
        "Dirrane",
        "Diskin",
        "Divenney",
        "Diver",
        "Divine",
        "Diviney",
        "Dixon",
        "Dobbin",
        "Dobbins",
        "Dogherty",
        "Doherty",
        "Dolan",
        "Donagher",
        "Donaldson",
        "Donegan",
        "Donlon",
        "Donnan",
        "Donnell",
        "Donnellan",
        "Donnelly",
        "Donoghue",
        "Donohoe",
        "Donohue",
        "Donovan",
        "Doody",
        "Dooey",
        "Doogan",
        "Doohan",
        "Doolan",
        "Dooley",
        "Doorty",
        "Doran",
        "Dordan",
        "Dore",
        "Dorgan",
        "Dornan",
        "Dorrian",
        "Doudigan",
        "Dowd",
        "Dower",
        "Dowey",
        "Dowley",
        "Dowling",
        "Downes",
        "Downey",
        "Downing",
        "Doyle",
        "Drennan",
        "Drian",
        "Driscoll",
        "Drohan",
        "Droney",
        "Drum",
        "Drumm",
        "Drummond",
        "Drummy",
        "Duane",
        "Duff",
        "Duffin",
        "Duffy",
        "Duggan",
        "Duhig",
        "Duhy",
        "Duignan",
        "Dulohery",
        "Duncan",
        "Dunford",
        "Dungan",
        "Dunleavey",
        "Dunleavy",
        "Dunne",
        "Dunning",
        "Dunny",
        "Dunphy",
        "Dunworth",
        "Durkan",
        "Durkin",
        "Durnan",
        "Durnin",
        "Durning",
        "Durrihy",
        "Dwane",
        "Dwyer",
        "Dyer",
        "Earl",
        "Earle",
        "Early",
        "Egan",
        "Eivers",
        "Elliot",
        "Elliott",
        "Ellis",
        "Elwood",
        "English",
        "Ennis",
        "Enright",
        "Ervin",
        "Ervine",
        "Eustace",
        "Evans",
        "Evoy",
        "Fadden",
        "Fadian",
        "Fagan",
        "Faherty",
        "Fahey",
        "Fahy",
        "Fair",
        "Fall",
        "Fallon",
        "Falvey",
        "Fannin",
        "Fanning",
        "Fannon",
        "Farell",
        "Farnan",
        "Farnon",
        "Farragher",
        "Farrell",
        "Farrelly",
        "Farren",
        "Farrissey",
        "Farrissy",
        "Farry",
        "Faulkner",
        "Faull",
        "Fay",
        "Fealy",
        "Fearon",
        "Fee",
        "Feehan",
        "Feeley",
        "Feely",
        "Feeney",
        "Feeny",
        "Fegan",
        "Fehan",
        "Fehilly",
        "Feighery",
        "Felban",
        "Fenelon",
        "Fenighty",
        "Fenlon",
        "Fennell",
        "Fennelly",
        "Fennessey",
        "Fenning",
        "Fenton",
        "Fergus",
        "Ferguson",
        "Ferris",
        "Ferriter",
        "Ferry",
        "Field",
        "Fielding",
        "Filban",
        "Filbin",
        "Finan",
        "Finegan",
        "Finlay",
        "Finn",
        "Finnegan",
        "Finneran",
        "Finnerty",
        "Finnucane",
        "Finucane",
        "Fisher",
        "Fitzgerald",
        "Fitzgibbon",
        "Fitzgibbons",
        "Fitzmartin",
        "Fitzmaurice",
        "Fitzpatrick",
        "Fitzsimmons",
        "Fitzsimons",
        "Flaherty",
        "Flahive",
        "Flanagan",
        "Flannagan",
        "Flannelly",
        "Flannery",
        "Flatley",
        "Flavin",
        "Fleming",
        "Flinn",
        "Flood",
        "Flynn",
        "Fogarty",
        "Folan",
        "Foley",
        "Foody",
        "Foran",
        "Forbes",
        "Ford",
        "Forde",
        "Forkin",
        "Fox",
        "Foy",
        "Foyle",
        "Fraher",
        "Frances",
        "Francis",
        "Franklin",
        "Frawley",
        "Freaney",
        "Freeley",
        "Freely",
        "Freeney",
        "Freil",
        "Fresh",
        "Friel",
        "Furey",
        "Fyfe",
        "Gaffney",
        "Gahan",
        "Gaine",
        "Gainey",
        "Gallagher",
        "Gallaher",
        "Gallen",
        "Galligan",
        "Gallivan",
        "Gallogly",
        "Galvin",
        "Ganley",
        "Ganly",
        "Gannon",
        "Garavan",
        "Garde",
        "Garety",
        "Gargan",
        "Garland",
        "Garraghy",
        "Garrahy",
        "Garrihy",
        "Garry",
        "Gartlan",
        "Gartland",
        "Garvey",
        "Garvin",
        "Gately",
        "Gaughan",
        "Gavaghan",
        "Gavican",
        "Gavigan",
        "Gavin",
        "Gay",
        "Gaynard",
        "Gaynor",
        "Geany",
        "Gearty",
        "Geary",
        "Geherty",
        "Geoghegan",
        "Geraghty",
        "Gerarghty",
        "Gibbon",
        "Gibbons",
        "Giblin",
        "Gibney",
        "Gibson",
        "Gilbane",
        "Gilbride",
        "Gildea",
        "Gilduff",
        "Giles",
        "Gilgunn",
        "Gilhooly",
        "Gill",
        "Gillan",
        "Gillen",
        "Gillespie",
        "Gillic",
        "Gillick",
        "Gilligan",
        "Gilliland",
        "Gillis",
        "Gillooly",
        "Gilmartin",
        "Gilmore",
        "Gilroy",
        "Gilsenan",
        "Ginevan",
        "Ging",
        "Ginnitty",
        "Ginnity",
        "Ginty",
        "Girvan",
        "Givern",
        "Glavin",
        "Glazier",
        "Gleasure",
        "Gleeson",
        "Glennon",
        "Gloster",
        "Glynn",
        "Godfrey",
        "Goff",
        "Gogan",
        "Gogarty",
        "Goggin",
        "Golden",
        "Golding",
        "Goldrick",
        "Gollan",
        "Goodwin",
        "Gorevan",
        "Gorey",
        "Gorham",
        "Gorman",
        "Gough",
        "Goulden",
        "Goulding",
        "Grace",
        "Grady",
        "Graham",
        "Grahams",
        "Grattan",
        "Gray",
        "Grealish",
        "Greally",
        "Greaney",
        "Greehy",
        "Greelish",
        "Greely",
        "Green",
        "Greene",
        "Grennan",
        "Grey",
        "Griffen",
        "Griffin",
        "Griffith",
        "Griffiths",
        "Groarke",
        "Grogan",
        "Groogan",
        "Growney",
        "Gubain",
        "Gubben",
        "Guerin",
        "Guihan",
        "Guilfoyle",
        "Guinan",
        "Guinane",
        "Guinevan",
        "Guiney",
        "Guinnane",
        "Guinness",
        "Guiry",
        "Gunn",
        "Gunning",
        "Gwynn",
        "Hackett",
        "Hagan",
        "Haggerty",
        "Hahessy",
        "Haire",
        "Hallahan",
        "Hallanan",
        "Halley",
        "Hallinan",
        "Hallissey",
        "Halloran",
        "Halpen",
        "Halpin",
        "Hamilton",
        "Hanafin",
        "Hanbury",
        "Hankard",
        "Hanley",
        "Hanlon",
        "Hanly",
        "Hanna",
        "Hannah",
        "Hanncard",
        "Hannigan",
        "Hannon",
        "Hanrahan",
        "Hanratty",
        "Hara",
        "Harahoe",
        "Haran",
        "Hardiman",
        "Hardy",
        "Hare",
        "Haren",
        "Hargadon",
        "Hargan",
        "Harkin",
        "Harkins",
        "Harley",
        "Harmon",
        "Harnett",
        "Harrihy",
        "Harrington",
        "Harris",
        "Harrison",
        "Harry",
        "Harte",
        "Hartigan",
        "Hartnett",
        "Harty",
        "Hassett",
        "Hastey",
        "Hastie",
        "Hastings",
        "Hasty",
        "Hatton",
        "Haugh",
        "Haughey",
        "Haverty",
        "Hawe",
        "Hawthorn",
        "Hayden",
        "Hayes",
        "Heaffy",
        "Healy",
        "Heaney",
        "Heaphy",
        "Hearn",
        "Hearne",
        "Hearty",
        "Heavey",
        "Heckett",
        "Hedderman",
        "Hedigan",
        "Heelan",
        "Heenan",
        "Heeney",
        "Heffernan",
        "Hefferon",
        "Heffron",
        "Hegarty",
        "Heggarty",
        "Hehir",
        "Helen",
        "Helery",
        "Hely",
        "Hempenstall",
        "Hendry",
        "Henebry",
        "Heneghan",
        "Henery",
        "Heney",
        "Hennebry",
        "Hennelley",
        "Hennelly",
        "Hennessey",
        "Hennessy",
        "Hennigan",
        "Henry",
        "Hepenstall",
        "Heraghty",
        "Heraty",
        "Herbert",
        "Hereward",
        "Herity",
        "Herlihy",
        "Hernon",
        "Heron",
        "Heskin",
        "Heslin",
        "Hession",
        "Hever",
        "Hewson",
        "Hickey",
        "Higgins",
        "Hilary",
        "Hillen",
        "Hillery",
        "Hilliard",
        "Hinney",
        "Hishon",
        "Histon",
        "Hoare",
        "Hoban",
        "Hodnett",
        "Hoey",
        "Hogan",
        "Holden",
        "Holland",
        "Hollins",
        "Hollywood",
        "Holmes",
        "Holohan",
        "Honan",
        "Hopkins",
        "Horan",
        "Hore",
        "Horgan",
        "Hosae",
        "Hosey",
        "Hoskins",
        "Hough",
        "Houlihan",
        "Hourican",
        "Hourigan",
        "Hourihane",
        "Howard",
        "Howe",
        "Howley",
        "Hughes",
        "Humphreys",
        "Hunt",
        "Hunter",
        "Hurd",
        "Hurley",
        "Hussey",
        "Hutchinson",
        "Hutchison",
        "Hutton",
        "Hyde",
        "Hyland",
        "Hyman",
        "Hynes",
        "Iago",
        "Igoe",
        "Inglis",
        "Ingoldsby",
        "Irvine",
        "Irwin",
        "Ivers",
        "Ivory",
        "Jackman",
        "Jackson",
        "Jameson",
        "Jennings",
        "Jiles",
        "Johnson",
        "Johnston",
        "Johnstone",
        "Jones",
        "Jordan",
        "Joyce",
        "Judge",
        "Kane",
        "Kangley",
        "Kavanagh",
        "Keady",
        "Kealey",
        "Keally",
        "Kealty",
        "Kealy",
        "Keane",
        "Keaney",
        "Keany",
        "Keapock",
        "Kearney",
        "Kearns",
        "Keary",
        "Keating",
        "Keaveney",
        "Keaveny",
        "Keeffe",
        "Keegan",
        "Keehan",
        "Keelan",
        "Keeley",
        "Keely",
        "Keenaghan",
        "Keenahan",
        "Keenan",
        "Keeney",
        "Keery",
        "Keevers",
        "Kehoe",
        "Keightley",
        "Kelleher",
        "Keller",
        "Kelly",
        "Kelvey",
        "Kenlan",
        "Kenlon",
        "Kenna",
        "Kenneally",
        "Kennedy",
        "Kennellan",
        "Kennelly",
        "Kenny",
        "Keogan",
        "Keogh",
        "Keoghan",
        "Keoghane",
        "Keohan",
        "Keohane",
        "Keown",
        "Kerin",
        "Kerins",
        "Kerley",
        "Kerlin",
        "Kermody",
        "Kernan",
        "Kerney",
        "Kerr",
        "Kerrigan",
        "Kerrisk",
        "Kerville",
        "Kerwick",
        "Kevane",
        "Keville",
        "Keyes",
        "Kidney",
        "Kiely",
        "Kieran",
        "Kierane",
        "Kierans",
        "Kiernan",
        "Kilawee",
        "Kilbane",
        "Kilbride",
        "Kilcoyne",
        "Kilday",
        "Kildea",
        "Kilduff",
        "Kilfoyle",
        "Kilgallen",
        "Kilgallon",
        "Kilhooly",
        "Kilkenny",
        "Killeen",
        "Killilea",
        "Killooly",
        "Killoran",
        "Killoughry",
        "Kilmartin",
        "Kilmore",
        "Kilroe",
        "Kilroy",
        "Kinaghan",
        "Kinahan",
        "King",
        "Kingston",
        "Kiniry",
        "Kinlan",
        "Kinlen",
        "Kinnane",
        "Kinnear",
        "Kinnegan",
        "Kinner",
        "Kinnerk",
        "Kinney",
        "Kinnon",
        "Kinny",
        "Kinsella",
        "Kirby",
        "Kirke",
        "Kirwan",
        "Kissane",
        "Kitson",
        "Kneafsey",
        "Knight",
        "Kyne",
        "Lacey",
        "Lacy",
        "Lafferty",
        "Laffey",
        "Lahey",
        "Lahiffe",
        "Lahy",
        "Laing",
        "Lally",
        "Lalor",
        "Lambe",
        "Lamont",
        "Landa",
        "Lande",
        "Landers",
        "Landy",
        "Lane",
        "Lang",
        "Langan",
        "Lanigan",
        "Lappin",
        "Lardner",
        "Largan",
        "Largey",
        "Larkin",
        "Lavan",
        "Lavell",
        "Lavelle",
        "Laverty",
        "Lavery",
        "Lavin",
        "Lawless",
        "Lawlor",
        "Leacy",
        "Leahy",
        "Leary",
        "Leavey",
        "Leddin",
        "Leddon",
        "Leddy",
        "Ledwich",
        "Ledwith",
        "Lee",
        "Leech",
        "Leen",
        "Leeney",
        "Lehane",
        "Leland",
        "Lenaghan",
        "Leneghan",
        "Lenehan",
        "Lenihan",
        "Lennane",
        "Lennon",
        "Leonard",
        "Lester",
        "Levan",
        "Leyden",
        "Leydon",
        "Liddane",
        "Liddy",
        "Lillis",
        "Lincoln",
        "Lindsay",
        "Linehan",
        "Linnane",
        "Linny",
        "Linskey",
        "Liston",
        "Little",
        "Loftus",
        "Logan",
        "Loghan",
        "Logue",
        "London",
        "Lonergan",
        "Long",
        "Longan",
        "Looney",
        "Lord",
        "Lordan",
        "Loughlin",
        "Loughnane",
        "Loughran",
        "Loughrey",
        "Loughry",
        "Lovett",
        "Lowe",
        "Lowney",
        "Lowry",
        "Lucey",
        "Lucid",
        "Lucitt",
        "Luddy",
        "Lundon",
        "Lunham",
        "Lunney",
        "Lunny",
        "Lyden",
        "Lydon",
        "Lynch",
        "Lynchechaun",
        "Lynchehaun",
        "Lyne",
        "Lyng",
        "Lynn",
        "Lynskey",
        "Lyons",
        "Lysaght",
        "Mac Breen",
        "MacAdoo",
        "MacAleavy",
        "MacAllen",
        "MacAloon",
        "MacAnally",
        "MacArt",
        "MacArthur",
        "MacBreen",
        "MacBride",
        "MacCaffrey",
        "MacCann",
        "MacCartan",
        "MacCarthy",
        "MacCarville",
        "MacClenaghan",
        "MacCole",
        "MacComisky",
        "MacConachy",
        "MacConnaghy",
        "MacCool",
        "MacCormack",
        "MacCurtin",
        "MacDermott",
        "MacDevitt",
        "MacDonagh",
        "MacDonald",
        "MacDonnell",
        "MacDougall",
        "MacDowell",
        "MacDwyer",
        "MacDyer",
        "MacEgan",
        "MacElgunn",
        "MacEver",
        "MacEvoy",
        "MacFadden",
        "MacFall",
        "MacFaull",
        "MacGee",
        "MacGeehan",
        "MacGill",
        "MacGilligan",
        "MacGing",
        "MacGinley",
        "MacGinnitty",
        "MacGinnity",
        "MacGinty",
        "MacGloin",
        "MacGlynn",
        "MacGovern",
        "MacGreal",
        "MacGroarty",
        "MacGuinness",
        "MacGurk",
        "MacHale",
        "MacHenry",
        "MacHugh",
        "MacInerney",
        "MacInnes",
        "MacKenna",
        "MacKeown",
        "MacKevitt",
        "MacLysaght",
        "MacMahon",
        "MacMonagle",
        "MacMorrow",
        "MacMullan",
        "MacMullen",
        "MacNabb",
        "MacNaboe",
        "MacNaboola",
        "MacNally",
        "MacNamara",
        "MacNamee",
        "MacNeela",
        "MacNeill",
        "MacNelis",
        "MacNulty",
        "MacPhilbin",
        "MacShea",
        "MacSweeney",
        "MacTiernan",
        "MacVeagh",
        "MacVeigh",
        "MacWilliams",
        "Macauley",
        "Macken",
        "Mackesey",
        "Mackey",
        "Mackle",
        "Maclean",
        "Macmillan",
        "Macrea",
        "Madden",
        "Maddock",
        "Maddy",
        "Madigan",
        "Magan",
        "Magann",
        "Magauran",
        "Magee",
        "Mageean",
        "Magennis",
        "Magennity",
        "Magill",
        "Maginn",
        "Magrath",
        "Maguire",
        "Mahedy",
        "Maher",
        "Mahon",
        "Mahoney",
        "Mahony",
        "Malley",
        "Mallon",
        "Malone",
        "Maloney",
        "Malowney",
        "Manahan",
        "Mangan",
        "Manley",
        "Mann",
        "Manning",
        "Mannion",
        "Mannix",
        "Mansell",
        "Mansfield",
        "Mara",
        "Markey",
        "Markham",
        "Marley",
        "Marnan",
        "Marren",
        "Marrinan",
        "Marron",
        "Marry",
        "Martin",
        "Martyn",
        "Masterson",
        "Matthews",
        "Maughan",
        "Maxwell",
        "May",
        "Maye",
        "McAdams",
        "McAleavy",
        "McAleenan",
        "McAleer",
        "McAlinney",
        "McAlister",
        "McAloon",
        "McAlunny",
        "McAnally",
        "McAndrew",
        "McAnulty",
        "McArdle",
        "McAreavey",
        "McAtee",
        "McAteer",
        "McAuley",
        "McAuliffe",
        "McAveigh",
        "McBreen",
        "McBride",
        "McBrien",
        "McCabe",
        "McCadam",
        "McCadden",
        "McCafferky",
        "McCafferty",
        "McCaffrey",
        "McCaffry",
        "McCahill",
        "McCall",
        "McCallion",
        "McCann",
        "McCardle",
        "McCarney",
        "McCarra",
        "McCarron",
        "McCartan",
        "McCarte",
        "McCarthy",
        "McCarville",
        "McCaughan",
        "McCaughey",
        "McCaul",
        "McCauley",
        "McCausland",
        "McCay",
        "McClean",
        "McClelland",
        "McCloskey",
        "McCluskey",
        "McColgan",
        "McColl",
        "McCollam",
        "McComiskey",
        "McConaghey",
        "McConaghy",
        "McConnell",
        "McConnon",
        "McCooey",
        "McCool",
        "McCorkill",
        "McCorley",
        "McCormick",
        "McCorry",
        "McCourt",
        "McCoy",
        "McCracken",
        "McCrann",
        "McCrea",
        "McCready",
        "McCreanor",
        "McCrory",
        "McCrossan",
        "McCrudden",
        "McCullagh",
        "McCullough",
        "McCumiskey",
        "McCumisky",
        "McCurdy",
        "McCurley",
        "McCurtin",
        "McCusker",
        "McDade",
        "McDaeid",
        "McDaid",
        "McDermod",
        "McDermott",
        "McDevitt",
        "McDonagh",
        "McDonald",
        "McDougald",
        "McDowell",
        "McDunphy",
        "McDwyer",
        "McDyer",
        "McElduff",
        "McElgunn",
        "McElhattin",
        "McEllistrim",
        "McElnay",
        "McElnea",
        "McElroe",
        "McElroy",
        "McElwaine",
        "McElwee",
        "McEnaney",
        "McEneaney",
        "McEnry",
        "McEntaggart",
        "McEntee",
        "McEvaddy",
        "McEvilly",
        "McEvoy",
        "McFadden",
        "McFall",
        "McFarland",
        "McFaull",
        "McGahey",
        "McGalligly",
        "McGann",
        "McGarraghy",
        "McGarrigle",
        "McGarry",
        "McGarvey",
        "McGauran",
        "McGaw",
        "McGeady",
        "McGee",
        "McGeehan",
        "McGeoghegan",
        "McGeown",
        "McGerr",
        "McGettigan",
        "McGettrick",
        "McGill",
        "McGillicuddy",
        "McGilligan",
        "McGilly",
        "McGilroy",
        "McGinley",
        "McGinnitty",
        "McGinty",
        "McGirl",
        "McGirr",
        "McGivern",
        "McGlinchey",
        "McGlinchy",
        "McGloin",
        "McGlynn",
        "McGoff",
        "McGoldrick",
        "McGonagle",
        "McGough",
        "McGourty",
        "McGovern",
        "McGowan",
        "McGowern",
        "McGrane",
        "McGrath",
        "McGreal",
        "McGrenehan",
        "McGroarty",
        "McGrory",
        "McGruddie",
        "McGruddy",
        "McGuigan",
        "McGuill",
        "McGuinn",
        "McGuinness",
        "McGuire",
        "McGuirk",
        "McGuirl",
        "McGurk",
        "McHale",
        "McHarry",
        "McHenry",
        "McHugh",
        "McIldownie",
        "McIlroe",
        "McIlroy",
        "McIlwee",
        "McIneely",
        "McInerney",
        "McInnes",
        "McIntyre",
        "McIvor",
        "McKaigue",
        "McKay",
        "McKee",
        "McKeegan",
        "McKeever",
        "McKelvey",
        "McKendry",
        "McKeniry",
        "McKenna",
        "McKenny",
        "McKeogh",
        "McKeon",
        "McKeown",
        "McKernon",
        "McKevitt",
        "McKie",
        "McKiernan",
        "McKillop",
        "McKing",
        "McKinley",
        "McKinney",
        "McKinnon",
        "McKnight",
        "McLaughlin",
        "McLaverty",
        "McLean",
        "McLeer",
        "McLeese",
        "McLeigh",
        "McLeod",
        "McLoon",
        "McLoone",
        "McLoughlin",
        "McMacken",
        "McMahon",
        "McManus",
        "McMaster",
        "McMenamin",
        "McMonagle",
        "McMorrow",
        "McMullen",
        "McMurrough",
        "McNaboe",
        "McNally",
        "McNamara",
        "McNamee",
        "McNaughton",
        "McNea",
        "McNealy",
        "McNee",
        "McNeely",
        "McNeill",
        "McNelis",
        "McNevin",
        "McNicholas",
        "McNicholl",
        "McNill",
        "McNulty",
        "McPartland",
        "McPartlin",
        "McPartlon",
        "McPherson",
        "McPhilbin",
        "McPhillips",
        "McPolin",
        "McQuade",
        "McQuaid",
        "McQueen",
        "McQuilkan",
        "McQuillan",
        "McQuillen",
        "McQuin",
        "McQuinn",
        "McRann",
        "McReady",
        "McRoarty",
        "McRory",
        "McShane",
        "McSharry",
        "McSheehy",
        "McTeague",
        "McTernan",
        "McTiernan",
        "McTigue",
        "McVeagh",
        "McVeigh",
        "McVicker",
        "McVitty",
        "McWalter",
        "Meaghan",
        "Meagher",
        "Meaney",
        "Meany",
        "Meara",
        "Mee",
        "Meehan",
        "Meenaghan",
        "Meenan",
        "Megaw",
        "Mehigan",
        "Melady",
        "Meldon",
        "Melia",
        "Melican",
        "Mellet",
        "Mellon",
        "Melody",
        "Melville",
        "Melvin",
        "Menton",
        "Mernagh",
        "Merrigan",
        "Merry",
        "Mescall",
        "Meskill",
        "Miley",
        "Millar",
        "Millea",
        "Miller",
        "Millet",
        "Millican",
        "Milligan",
        "Milmo",
        "Milne",
        "Milroy",
        "Minihan",
        "Minihane",
        "Minogue",
        "Miscell",
        "Miskell",
        "Mitchell",
        "Moan",
        "Moffatt",
        "Moffit",
        "Mohan",
        "Moher",
        "Molloy",
        "Moloney",
        "Molyneux",
        "Monaghan",
        "Monagle",
        "Monahan",
        "Mongan",
        "Monk",
        "Monks",
        "Monroe",
        "Montague",
        "Montgomery",
        "Moody",
        "Moone",
        "Mooney",
        "Moore",
        "Morahan",
        "Moran",
        "Morgan",
        "Moriarty",
        "Morley",
        "Mornane",
        "Moroney",
        "Morrin",
        "Morris",
        "Morrison",
        "Morrissey",
        "Morrow",
        "Mountain",
        "Moy",
        "Moylan",
        "Moynihan",
        "Mulcahy",
        "Mulcair",
        "Muldoon",
        "Muldowney",
        "Mulgrave",
        "Mulgrew",
        "Mulhare",
        "Mulhern",
        "Mulkerrin",
        "Mullaghan",
        "Mullaly",
        "Mullan",
        "Mullane",
        "Mullaney",
        "Mullany",
        "Mullarkey",
        "Mullen",
        "Mullery",
        "Mulligan",
        "Mullin",
        "Mullins",
        "Mullooly",
        "Mullooney",
        "Mulloughney",
        "Mulloy",
        "Mulqueen",
        "Mulqueeny",
        "Mulrain",
        "Mulrooney",
        "Mulroy",
        "Mulry",
        "Mulryan",
        "Mulvany",
        "Mulvenna",
        "Mulvey",
        "Mulvihill",
        "Mulvin",
        "Mulvy",
        "Munnelly",
        "Munroe",
        "Murae",
        "Murnane",
        "Murnin",
        "Murphy",
        "Murray",
        "Murrihy",
        "Murtagh",
        "Myers",
        "Myles",
        "Nagle",
        "Nallon",
        "Nally",
        "Nalty",
        "Nangle",
        "Nary",
        "Nash",
        "Naughton",
        "Nea",
        "Nealon",
        "Neary",
        "Nee",
        "Needham",
        "Neehan",
        "Neelan",
        "Neelin",
        "Neenan",
        "Neilan",
        "Neilian",
        "Neill",
        "Neligan",
        "Nelis",
        "Nelson",
        "Nestor",
        "Neville",
        "Nevin",
        "Neylon",
        "Nicholas",
        "Nicholls",
        "Nicholson",
        "Niland",
        "Nixon",
        "Nolan",
        "Nolty",
        "Noonan",
        "Noone",
        "Norris",
        "Norry",
        "Norton",
        "Nugent",
        "Nulty",
        "Nunne",
        "Nyhan",
        "O'Beirn",
        "O'Beirne",
        "O'Boyle",
        "O'Brassil",
        "O'Brazil",
        "O'Brennan",
        "O'Brien",
        "O'Brown",
        "O'Bryan",
        "O'Bryen",
        "O'Byrne",
        "O'Cadden",
        "O'Cafferky",
        "O'Callaghan",
        "O'Carolan",
        "O'Carroll",
        "O'Casey",
        "O'Cassidy",
        "O'Cleary",
        "O'Clery",
        "O'Connell",
        "O'Connor",
        "O'Crohan",
        "O'Crowley",
        "O'Curry",
        "O'Daly",
        "O'Dea",
        "O'Devanney",
        "O'Devenny",
        "O'Doherty",
        "O'Donnell",
        "O'Donoghue",
        "O'Donohoe",
        "O'Donovan",
        "O'Dowd",
        "O'Driscoll",
        "O'Duffy",
        "O'Dwyer",
        "O'Farrell",
        "O'Farrelly",
        "O'Flaherty",
        "O'Flynn",
        "O'Freil",
        "O'Friel",
        "O'Gallagher",
        "O'Gara",
        "O'Goldrick",
        "O'Gorman",
        "O'Gowan",
        "O'Grady",
        "O'Growney",
        "O'Hagan",
        "O'Haire",
        "O'Halloran",
        "O'Hanlon",
        "O'Hanrahan",
        "O'Hara",
        "O'Hare",
        "O'Haughey",
        "O'Hea",
        "O'Hegarty",
        "O'Hehir",
        "O'Herlihy",
        "O'Hickey",
        "O'Higgins",
        "O'Hora",
        "O'Houlihan",
        "O'Hurley",
        "O'Hussey",
        "O'Kane",
        "O'Kearney",
        "O'Keefe",
        "O'Keeffe",
        "O'Kelly",
        "O'Kennedy",
        "O'Kieve",
        "O'Leary",
        "O'Loan",
        "O'Looney",
        "O'Loughlin",
        "O'Loughlinn",
        "O'Mahoney",
        "O'Mahony",
        "O'Malley",
        "O'Mara",
        "O'Meara",
        "O'Mooney",
        "O'Moore",
        "O'Mullan",
        "O'Murnaghan",
        "O'Neill",
        "O'Nolan",
        "O'Rafferty",
        "O'Rahilly",
        "O'Reardon",
        "O'Regan",
        "O'Reilly",
        "O'Riordan",
        "O'Rooney",
        "O'Rourke",
        "O'Ruane",
        "O'Ryan",
        "O'Scannell",
        "O'Shannon",
        "O'Sharkey",
        "O'Shaughnessy",
        "O'Shea",
        "O'Sheehan",
        "O'Sheil",
        "O'Shiel",
        "O'Sullivan",
        "O'Sweeney",
        "O'Tierney",
        "O'Togher",
        "O'Toole",
        "Ormsby",
        "Owens",
        "Padden",
        "Parker",
        "Parsons",
        "Paten",
        "Patterson",
        "Patton",
        "Paul",
        "Pender",
        "Perkins",
        "Perri",
        "Perry",
        "Peyton",
        "Phayre",
        "Phelan",
        "Philban",
        "Philbin",
        "Phillips",
        "Piggott",
        "Pigott",
        "Pinder",
        "Plover",
        "Poland",
        "Powell",
        "Power",
        "Prendergast",
        "Prial",
        "Price",
        "Pringle",
        "Pryal",
        "Purcell",
        "Quaide",
        "Qualter",
        "Queally",
        "Queenane",
        "Quigley",
        "Quigney",
        "Quill",
        "Quillinan",
        "Quilty",
        "Quin",
        "Quinlan",
        "Quinlivan",
        "Quinn",
        "Quinney",
        "Quinny",
        "Quirke",
        "Rabbitte",
        "Rafferty",
        "Rafter",
        "Raftery",
        "Raftis",
        "Rahilly",
        "Raight",
        "Rails",
        "Raleigh",
        "Randles",
        "Raney",
        "Raol",
        "Rattigan",
        "Rawley",
        "Rayel",
        "Rea",
        "Reade",
        "Reardon",
        "Reavy",
        "Reddin",
        "Reddy",
        "Redican",
        "Redmond",
        "Reen",
        "Regan",
        "Reid",
        "Reidy",
        "Reilly",
        "Renehan",
        "Reynell",
        "Reynolds",
        "Reynoldson",
        "Rhatigan",
        "Rhattigan",
        "Rice",
        "Richard",
        "Richards",
        "Richardson",
        "Richey",
        "Richie",
        "Ridge",
        "Rigney",
        "Riney",
        "Ring",
        "Rinn",
        "Riordan",
        "Roach",
        "Roache",
        "Roarke",
        "Roarty",
        "Roberts",
        "Robertson",
        "Robeson",
        "Robinson",
        "Roche",
        "Rock",
        "Rodden",
        "Roddy",
        "Roden",
        "Rodgers",
        "Roe",
        "Rogers",
        "Rogerson",
        "Rohan",
        "Roland",
        "Ronan",
        "Ronayne",
        "Rooney",
        "Rose",
        "Ross",
        "Rourke",
        "Rowan",
        "Rowe",
        "Rowley",
        "Ruane",
        "Rudden",
        "Ruddy",
        "Rudkins",
        "Rush",
        "Russell",
        "Ryan",
        "Ryder",
        "Ryle",
        "Rynn",
        "Rynne",
        "Salmon",
        "Sammon",
        "Saors",
        "Sarsfield",
        "Sayers",
        "Scallan",
        "Scallon",
        "Scally",
        "Scanlan",
        "Scanlon",
        "Scannell",
        "Scollan",
        "Scriven",
        "Scullion",
        "Scully",
        "Seally",
        "Sealy",
        "Sears",
        "Seery",
        "Segerson",
        "Segersun",
        "Setrick",
        "Sexton",
        "Shaffrey",
        "Shanahan",
        "Shanley",
        "Shannon",
        "Shanny",
        "Sharkey",
        "Sharpe",
        "Sharry",
        "Shaughnessy",
        "Shea",
        "Sheahan",
        "Sheane",
        "Sheedy",
        "Sheehan",
        "Sheehy",
        "Sheeran",
        "Sheerin",
        "Sheil",
        "Sheilds",
        "Sheridan",
        "Sherlock",
        "Sherry",
        "Shevlin",
        "Shiel",
        "Shields",
        "Shiels",
        "Shine",
        "Short",
        "Shortt",
        "Sigerson",
        "Silk",
        "Silke",
        "Simmon",
        "Simmonds",
        "Simmons",
        "Sinan",
        "Sinnott",
        "Skally",
        "Skeahan",
        "Skeffington",
        "Skehan",
        "Skelly",
        "Skivington",
        "Slamon",
        "Slattery",
        "Slevin",
        "Sloan",
        "Sloane",
        "Slowey",
        "Slyne",
        "Small",
        "Smith",
        "Smullen",
        "Smyth",
        "Smythe",
        "Somers",
        "Soolaghan",
        "Spain",
        "Spencer",
        "Spenser",
        "Spillane",
        "Stack",
        "Stanton",
        "Stapleton",
        "Staunton",
        "Steed",
        "Stenson",
        "Stephens",
        "Stephenson",
        "Steward",
        "Stewart",
        "Stoices",
        "Stokes",
        "Stone",
        "Storey",
        "Story",
        "Stuart",
        "Sugrue",
        "Sullivan",
        "Summerville",
        "Supple",
        "Sweeney",
        "Sweeny",
        "Swift",
        "Swords",
        "Synnott",
        "Taggart",
        "Tangney",
        "Tansey",
        "Tarpey",
        "Taylor",
        "Teahan",
        "Tehan",
        "Ternan",
        "Terry",
        "Thom",
        "Thomas",
        "Thompson",
        "Thornton",
        "Tiernan",
        "Tierney",
        "Timlin",
        "Timoney",
        "Timony",
        "Tinney",
        "Toal",
        "Tobin",
        "Togher",
        "Tohall",
        "Tolan",
        "Tolin",
        "Toms",
        "Toner",
        "Toolan",
        "Toole",
        "Toolin",
        "Toolis",
        "Tooman",
        "Toomey",
        "Tormay",
        "Tormey",
        "Torpey",
        "Torrence",
        "Torrens",
        "Tracey",
        "Tracy",
        "Trainor",
        "Travers",
        "Traynor",
        "Treacy",
        "Treanor",
        "Trenor",
        "Troy",
        "Tubridy",
        "Tully",
        "Tuohey",
        "Tuohy",
        "Turley",
        "Tutty",
        "Twohey",
        "Twohig",
        "Twomey",
        "Tynan",
        "Tyrrell",
        "Uniacke",
        "Uniaque",
        "Vaughan",
        "Veale",
        "Victory",
        "Wade",
        "Waldron",
        "Wall",
        "Wallace",
        "Walls",
        "Walsh",
        "Walshe",
        "Walter",
        "Walters",
        "Ward",
        "Warren",
        "Waters",
        "Watters",
        "Watts",
        "Weaver",
        "Weever",
        "Weir",
        "Weldon",
        "Whalen",
        "Whelan",
        "Whelehan",
        "White",
        "Whitty",
        "Whyte",
        "Wilkins",
        "Wilkinson",
        "Williams",
        "Wilson",
        "Winters",
        "Wolfe",
        "Woods",
        "Woolley",
        "Woulfe",
        "Wren",
        "Wrenn",
        "Wright",
        "Wrynn",
        "Wynne",
        "Young",
        "de Courcey",
        "de Lacy",
        "Ó Corra",
    )

    prefixes_female = ("Mrs.", "Ms.", "Miss", "Dr.")
    prefixes_male = ("Mr.", "Dr.")



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}",
        "{{first_name_male}} {{last_name_male}}-{{last_name_male}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}",
        "{{first_name_female}} {{last_name_female}}-{{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
        "{{prefix_male}} {{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
    )

    # names from https://en.wikipedia.org/wiki/Ghanaian_name,
    # https://buzzghana.com/ghanaian-names/,
    # https://en.wikipedia.org/wiki/Akan_names,

    first_names_male = (
        "Aaron",
        "Abeiku",
        "Adam",
        "Adrian",
        "Akwesi",
        "Albert",
        "Alex",
        "Alexander",
        "Andrew",
        "Anthony",
        "Antony",
        "Arthur",
        "Ben",
        "Benjamin",
        "Bernard",
        "Bruce",
        "Carl",
        "Charles",
        "Christian",
        "Clifford",
        "Colins",
        "Daniel",
        "Danny",
        "David",
        "Denis",
        "Dennis",
        "Derrick",
        "Dominic",
        "Donald",
        "Douglas",
        "Duncan",
        "Edward",
        "Ekow",
        "Elliot",
        "Elliott",
        "Eric",
        "Fiifi",
        "Francis",
        "Frank",
        "Frederick",
        "George",
        "Gerald",
        "Gordon",
        "Graham",
        "Gregory",
        "Harry",
        "Henry",
        "Howard",
        "Isaac",
        "Akwasi",
        "Jack",
        "Jacob",
        "Jake",
        "James",
        "Jason",
        "Jeffrey",
        "Jeremy",
        "Joe",
        "Joel",
        "John",
        "Jonathan",
        "Joojo",
        "Joseph",
        "Josh",
        "Joshua",
        "Josiah",
        "Julian",
        "Justin",
        "Karl",
        "Kenneth",
        "Kevin",
        "Kofi",
        "Kojo",
        "Kujoe",
        "Kwabena",
        "Kwadwo",
        "Kwaku",
        "Kwame",
        "Kwamena",
        "Kwasi",
        "Kweku",
        "Kwesi",
        "Kyle",
        "Lawrence",
        "Leslie",
        "Louis",
        "Luke",
        "Malcolm",
        "Marcus",
        "Mark",
        "Martin",
        "Mathew",
        "Matthew",
        "Max",
        "Michael",
        "Nathan",
        "Nicholas",
        "Nigel",
        "Oliver",
        "Patrick",
        "Paul",
        "Peter",
        "Philip",
        "Phillip",
        "Raymond",
        "Richard",
        "Robert",
        "Roger",
        "Ronald",
        "Russell",
        "Sam",
        "Samuel",
        "Shaun",
        "Simon",
        "Stanley",
        "Stephen",
        "Steven",
        "Terence",
        "Thomas",
        "Timothy",
        "Tom",
        "Tony",
        "Victor",
        "Vincent",
        "William",
        "Yaw",
    )

    first_names_female = (
        "Aba",
        "Abena",
        "Abigail",
        "Adwoa",
        "Afia",
        "Afua",
        "Akos",
        "Akosua",
        "Akua",
        "Akumaa",
        "Alice",
        "Ama",
        "Amanda",
        "Amber",
        "Amelia",
        "Angela",
        "Ann",
        "Annette",
        "Awesi",
        "Baaba",
        "Barbara",
        "Beatrice",
        "COmfort",
        "Caroline",
        "Catherine",
        "Charlotte",
        "Christina",
        "Comfort",
        "Constance",
        "Danielle",
        "Deborah",
        "Debra",
        "Denise",
        "Dora",
        "Dorcas",
        "Dorothy",
        "Eliabeth",
        "Elizabeth",
        "Emily",
        "Emma",
        "Ernestina",
        "Esi",
        "Eunice",
        "Felicia",
        "Francesca",
        "Gemma",
        "Georgia",
        "Georgina",
        "Gifty",
        "Grace",
        "Grace",
        "Hannabel",
        "Hannah",
        "Harriet",
        "Helen",
        "Irene",
        "Janet",
        "Janet",
        "Janice",
        "Jasmine",
        "Jennifer",
        "Jessica",
        "Jill",
        "Joanna",
        "Josephine",
        "Joyce",
        "Joyce",
        "Judith",
        "Julia",
        "Juliana",
        "Julie",
        "Karen",
        "Kate",
        "Katherine",
        "Katy",
        "Lawrencia",
        "Linda",
        "Lisa",
        "Lorraine",
        "Lucy",
        "Lucy",
        "Lydia",
        "Lydia",
        "Mandy",
        "Margaret",
        "Margaret",
        "Maria",
        "Marian",
        "Marilyn",
        "Mary",
        "Mary",
        "Maureen",
        "Michelle",
        "Millicent",
        "Nana Ama",
        "Naomi",
        "Natalie",
        "Natasha",
        "Nicola",
        "Nimakoah",
        "Olivia",
        "Pamela",
        "Patricia",
        "Paula",
        "Priscilla",
        "Rachael",
        "Rachel",
        "Rebecca",
        "Rebecca",
        "Regina",
        "Rita",
        "Roselyn",
        "Rosemary",
        "Rosemary",
        "Ruth",
        "Salomey",
        "Samantha",
        "Sandra",
        "Sarah",
        "Sarah",
        "Sarah",
        "Sharon",
        "Sheila",
        "Shirley",
        "Stephanie",
        "Susan",
        "Susan",
        "Sylvia",
        "Teresa",
        "Tina",
        "Tracy",
        "Vanessa",
        "Veronica",
        "Victoria",
        "Vida",
        "Wendy",
        "Yaa",
        "Yvonne",
    )

    first_names = first_names_male + first_names_female

    last_names_male = (
        "Acheampong",
        "Adomah",
        "Adomako",
        "Adu",
        "Adusei",
        "Adutwum",
        "Afirifa",
        "Afoakwa",
        "Agyapong",
        "Agyapong",
        "Agyare",
        "Agyei",
        "Agyemang",
        "Ahortor",
        "Akoto",
        "Akowua",
        "Akyeamfuɔ",
        "Akyeampong",
        "Akyena",
        "Akyerεko",
        "Amo",
        "Amoa",
        "Amoako",
        "Amoasi",
        "Ampadu",
        "Ampofo",
        "Amponsah",
        "Andorful",
        "Ankra",
        "Anokye",
        "Ansa",
        "Antwi",
        "Antwi",
        "Appia",
        "Appiah",
        "Asamoa",
        "Asamoah",
        "Asante",
        "Asare",
        "Asenso",
        "Asiama",
        "Asiedu",
        "Ata",
        "Awuah",
        "Baa",
        "Baafi",
        "Baah",
        "Baawia",
        "Badu",
        "Boadi",
        "Boadu",
        "Boahen",
        "Boakye",
        "Boaten",
        "Boateng",
        "Bona",
        "Bonsra",
        "Bonsu",
        "Daako",
        "Danso",
        "Darko",
        "Donkor",
        "Duah",
        "Dwamena",
        "Fofie",
        "Fosu",
        "Gyamfi",
        "Gyasi",
        "Karikari",
        "Koomson",
        "Kumi",
        "Kusi",
        "Kwaakye",
        "Kwarteng",
        "Kyei",
        "Mensa",
        "Mensah",
        "Nkansa",
        "Nkansah",
        "Nkrumah",
        "Nsia",
        "Nti",
        "Ntiamoa",
        "Ntim",
        "Nyaako",
        "Nyame",
        "Nyantakyi",
        "Obeng",
        "Ofori",
        "Ofosu",
        "Okyere",
        "Omani",
        "Opoku",
        "Oppong",
        "Opuku",
        "Osei",
        "Oti",
        "Otiwa",
        "Otuo",
        "Owusu",
        "Prempeh",
        "Quartey",
        "Safo",
        "Sarpong",
        "Takyi",
        "Tawia",
        "Tutu",
        "Tweneboa",
        "Twumasi",
        "Wiafe",
        "Yaamoa",
        "Yawson",
        "Yeboa",
        "Yeboah",
        "Yirenkyi",
    )

    last_names_female = (
        "Aboraa",
        "Abrafi",
        "Acheampong",
        "Adoma",
        "Adomah",
        "Adomako",
        "Adu",
        "Adusei",
        "Adutwum",
        "Adutwumwaa",
        "Adwubi",
        "Afirifa",
        "Afoakwa",
        "Afrakomaa",
        "Agyapomaa",
        "Agyapong",
        "Agyapong",
        "Agyare",
        "Agyei",
        "Agyeiwaa",
        "Agyemang",
        "Ahortor",
        "Akoaa",
        "Akoto",
        "Akowua",
        "Akyaa",
        "Akyeamfuɔ",
        "Akyeampomaa",
        "Akyeampong",
        "Akyena",
        "Akyerε",
        "Akyerεko",
        "Akɔmaa",
        "Amo",
        "Amoa",
        "Amoako",
        "Amoakowaa",
        "Amoanimaa",
        "Amoasi",
        "Ampadu",
        "Ampofo",
        "Ampofowaa",
        "Ampoma",
        "Amponsa",
        "Amponsa",
        "Andorful",
        "Anima",
        "Ankra",
        "Anokye",
        "Ansa",
        "Ansomaa",
        "Ansomah",
        "Antwi",
        "Antwi",
        "Antwiwaa",
        "Appia",
        "Appiah",
        "Asamoa",
        "Asamoah",
        "Asante",
        "Asantewaa",
        "Asare",
        "Asenso",
        "Asiama",
        "Asiedu",
        "Asieduwaa",
        "Ata",
        "Ataa",
        "Awuah",
        "Baa",
        "Baafi",
        "Baah",
        "Baawia",
        "Badu",
        "Boadi",
        "Boadu",
        "Boahen",
        "Boakye",
        "Boakye",
        "Boakyewaa",
        "Boatemaa",
        "Boatemaah",
        "Boaten",
        "Boateng",
        "Bona",
        "Bonsra",
        "Bonsu",
        "Daako",
        "Daakoaa",
        "Danso",
        "Darko",
        "Donkor",
        "Duah",
        "Dufie",
        "Dwamena",
        "Fofie",
        "Foriwaa",
        "Fosu",
        "Fosua",
        "Frema",
        "Frimpomaa",
        "Gyamfi",
        "Gyamfi",
        "Gyamfiaa",
        "Gyasi",
        "Gyasiwaa",
        "Karikari",
        "Koomson",
        "Kumi",
        "Kusi",
        "Kusiwaa",
        "Kwaakye",
        "Kwaakyewaa",
        "Kwartemaa",
        "Kwarteng",
        "Kyei",
        "Kyeiwaa",
        "Kyerewaa",
        "Mansa",
        "Mensa",
        "Mensah",
        "Nkansa",
        "Nkansah",
        "Nkrumah",
        "Nsia",
        "Nti",
        "Ntiamoa",
        "Ntim",
        "Nyaako",
        "Nyaakoaa",
        "Nyame",
        "Nyantakyi",
        "Obeng",
        "Ofori",
        "Ofosu",
        "Okyere",
        "Okyere",
        "Omani",
        "Opoku",
        "Oppong",
        "Opuku",
        "Osei",
        "Oti",
        "Otiwa",
        "Otuo",
        "Owusu",
        "Owusuwaa",
        "Pokuaa",
        "Pomaa",
        "Prempeh",
        "Quartey",
        "Safo",
        "Safo",
        "Safoaa",
        "Sarpong",
        "Serwaa",
        "Takyi",
        "Tawia",
        "Tiwaa",
        "Tutu",
        "Tweneboa",
        "Twumasi",
        "Wiafe",
        "Yaamoa",
        "Yawson",
        "Yeboa",
        "Yeboah",
        "Yirenkyi",
    )

    last_names = last_names_male + last_names_female

    prefixes_female = (
        "Mrs.",
        "Ms.",
        "Miss",
        "Dr.",
        "Mama",
        "Maame",
        "Awura",
        "Sista",
        "Osofo Maame",
    )

    prefixes_male = ("Mr.", "Dr.", "Agya", "Owura", "Osofo")



import random as random_module
import re

from typing import TYPE_CHECKING, Any, Callable, Dict, Hashable, List, Optional, Type, Union

from .typing import SeedType

if TYPE_CHECKING:
    from .providers import BaseProvider

_re_token = re.compile(r"\{\{\s*(\w+)(:\s*\w+?)?\s*\}\}")
random = random_module.Random()
mod_random = random  # compat with name released in 0.8


Sentinel = object()


class Generator:
    __config: Dict[str, Dict[Hashable, Any]] = {
        "arguments": {},
    }

    _is_seeded = False
    _global_seed = Sentinel

    def __init__(self, **config: Dict) -> None:
        self.providers: List["BaseProvider"] = []
        self.__config = dict(list(self.__config.items()) + list(config.items()))
        self.__random = random

    def add_provider(self, provider: Union["BaseProvider", Type["BaseProvider"]]) -> None:
        if isinstance(provider, type):
            provider = provider(self)

        self.providers.insert(0, provider)

        for method_name in dir(provider):
            # skip 'private' method
            if method_name.startswith("_"):
                continue

            faker_function = getattr(provider, method_name)

            if callable(faker_function):
                # add all faker method to generator
                self.set_formatter(method_name, faker_function)

    def provider(self, name: str) -> Optional["BaseProvider"]:
        try:
            lst = [p for p in self.get_providers() if hasattr(p, "__provider__") and p.__provider__ == name.lower()]
            return lst[0]
        except IndexError:
            return None

    def get_providers(self) -> List["BaseProvider"]:
        """Returns added providers."""
        return self.providers

    @property
    def random(self) -> random_module.Random:
        return self.__random

    @random.setter
    def random(self, value: random_module.Random) -> None:
        self.__random = value

    def seed_instance(self, seed: Optional[SeedType] = None) -> "Generator":
        """Calls random.seed"""
        if self.__random == random:
            # create per-instance random obj when first time seed_instance() is
            # called
            self.__random = random_module.Random()
        self.__random.seed(seed)
        self._is_seeded = True
        return self

    @classmethod
    def seed(cls, seed: Optional[SeedType] = None) -> None:
        random.seed(seed)
        cls._global_seed = seed
        cls._is_seeded = True

    def format(self, formatter: str, *args: Any, **kwargs: Any) -> str:
        """
        This is a secure way to make a fake from another Provider.
        """
        return self.get_formatter(formatter)(*args, **kwargs)

    def get_formatter(self, formatter: str) -> Callable:
        try:
            return getattr(self, formatter)
        except AttributeError:
            if "locale" in self.__config:
                msg = f'Unknown formatter {formatter!r} with locale {self.__config["locale"]!r}'
            else:
                raise AttributeError(f"Unknown formatter {formatter!r}")
            raise AttributeError(msg)

    def set_formatter(self, name: str, formatter: Callable) -> None:
        """
        This method adds a provider method to generator.
        Override this method to add some decoration or logging stuff.
        """
        setattr(self, name, formatter)

    def set_arguments(self, group: str, argument: str, value: Optional[Any] = None) -> None:
        """
        Creates an argument group, with an individual argument or a dictionary
        of arguments. The argument groups is used to apply arguments to tokens,
        when using the generator.parse() method. To further manage argument
        groups, use get_arguments() and del_arguments() methods.

        generator.set_arguments('small', 'max_value', 10)
        generator.set_arguments('small', {'min_value': 5, 'max_value': 10})
        """
        if group not in self.__config["arguments"]:
            self.__config["arguments"][group] = {}

        if isinstance(argument, dict):
            self.__config["arguments"][group] = argument
        elif not isinstance(argument, str):
            raise ValueError("Arguments must be either a string or dictionary")
        else:
            self.__config["arguments"][group][argument] = value

    def get_arguments(self, group: str, argument: Optional[str] = None) -> Any:
        """
        Get the value of an argument configured within a argument group, or
        the entire group as a dictionary. Used in conjunction with the
        set_arguments() method.

        generator.get_arguments('small', 'max_value')
        generator.get_arguments('small')
        """
        if group in self.__config["arguments"] and argument:
            result = self.__config["arguments"][group].get(argument)
        else:
            result = self.__config["arguments"].get(group)

        return result

    def del_arguments(self, group: str, argument: Optional[str] = None) -> Any:
        """
        Delete an argument from an argument group or the entire argument group.
        Used in conjunction with the set_arguments() method.

        generator.del_arguments('small')
        generator.del_arguments('small', 'max_value')
        """
        if group in self.__config["arguments"]:
            if argument:
                result = self.__config["arguments"][group].pop(argument)
            else:
                result = self.__config["arguments"].pop(group)
        else:
            result = None

        return result

    def parse(self, text: str) -> str:
        """
        Replaces tokens like '{{ tokenName }}' or '{{tokenName}}' in a string with
        the result from the token method call. Arguments can be parsed by using an
        argument group. For more information on the use of argument groups, please
        refer to the set_arguments() method.

        Example:

        generator.set_arguments('red_rgb', {'hue': 'red', 'color_format': 'rgb'})
        generator.set_arguments('small', 'max_value', 10)

        generator.parse('{{ color:red_rgb }} - {{ pyint:small }}')
        """
        return _re_token.sub(self.__format_token, text)

    def __format_token(self, matches):
        formatter, argument_group = list(matches.groups())
        argument_group = argument_group.lstrip(":").strip() if argument_group else ""

        if argument_group:
            try:
                arguments = self.__config["arguments"][argument_group]
            except KeyError:
                raise AttributeError(f"Unknown argument group {argument_group!r}")

            formatted = str(self.format(formatter, **arguments))
        else:
            formatted = str(self.format(formatter))

        return "".join(formatted)



from collections import OrderedDict
from typing import Optional

from randum.providers.credit_card import Provider as CreditCardProvider
from randum.typing import CardType, CreditCard


class Provider(CreditCardProvider):
    """Custom credit card provider for the zh_CN locale."""

    prefix_unionpay = ["62"]  # UnionPay cards typically start with 62
    prefix_visa = ["4"]
    prefix_mastercard = ["51", "52", "53", "54", "55"]

    credit_card_types = OrderedDict(
        (
            ("unionpay", CreditCard("UnionPay", prefix_unionpay, security_code="CVN2")),
            ("visa", CreditCard("Visa", prefix_visa, security_code="CVV2")),
            ("mastercard", CreditCard("Mastercard", prefix_mastercard, security_code="CVC2")),
        )
    )

    def credit_card_full(self, card_type: Optional[CardType] = None) -> str:
        """Generate a full Chinese credit card with details."""
        card = self._credit_card_type(card_type)
        tpl = "{provider}\n{owner}\n{number} {expire_date}\n{security}: {security_nb}\n{issuer}"
        tpl = tpl.format(
            provider=card.name,
            owner=self.generator.parse("{{first_name}}{{last_name}}"),
            number=self.credit_card_number(card),
            expire_date=self.credit_card_expire(),
            security=card.security_code,
            security_nb=self.credit_card_security_code(card),
            issuer=self.generator.parse("{{bank}}"),
        )
        return self.generator.parse(tpl)



from randum.providers.person.bn_BD import translate_to_bengali_digits

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    area_names = (
        "আলি",
        "আলম",
        "অভয়",
        "আনোয়ার",
        "ব্রাহ্মণ",
        "বটিয়া",
        "বাঘার",
        "বেগম",
        "বিজয়",
        "বন্দর",
        "বালিয়া",
        "বাজিত",
        "বাকের",
        "বোরহান",
        "বকশী",
        "বদর",
        "বিরাম",
        "বিশ্বনাথ",
        "চৌদ্দ",
        "চিতল",
        "দাউদ",
        "দৌলত",
        "দেব",
        "দেবী",
        "ইসলাম",
        "ফুল",
        "ফকির",
        "ফটিক",
        "গোপাল",
        "গৌর",
        "হাজী",
        "হরিরাম",
        "হোসেন",
        "হাকিম",
        "জীবন",
        "জগন্নাথ",
        "কুমার",
        "কালী",
        "কেশব",
        "কুতুব",
        "কবির",
        "কালিয়া",
        "করিম",
        "কাজী",
        "কমল",
        "লাল",
        "মুরাদ",
        "মনোহর",
        "মির",
        "মহেশ",
        "মোড়ল",
        "মোল্লা",
        "মোহাম্মদ",
        "মনিরাম",
        "মানিক",
        "মির্জা",
        "মধু",
        "মোহন",
        "মহাদেব",
        "মাধব",
        "নাসির",
        "নড়িয়া",
        "নাজির",
        "নালিতা",
        "নন্দী",
        "ওসমানী",
        "পাইক",
        "পলাশ",
        "পার্বতী",
        "রাম",
        "রায়",
        "রানী",
        "সোনা",
        "শরণ",
        "শ্যাম",
        "সুবর্ণ",
        "সিরাজ",
        "সখি",
        "সদর",
        "সুন্দর",
        "সৈয়দ",
        "শাজাহান",
        "শান্তি",
        "শিব",
        "তের",
        "তারা",
        "উজির",
    )

    building_names = (
        "বাড়ী নং",
        "বিল্ডিং নং",
        "বাসা নং",
        "হোল্ডিং নং",
    )

    building_number_formats = ("%", "%#", "%##")

    city_prefixes = ("উত্তর", "পূর্ব", "পশ্চিম", "দক্ষিণ", "মধ্য", "নতুন", "পুরাতন")

    city_suffixes = (
        "বাজার",
        "বাড়ি",
        "চর",
        "দিয়া",
        "ডাঙ্গা",
        "গঞ্জ",
        "গ্রাম",
        "গাঁও",
        "গাঁ",
        "গড়",
        "হাট",
        "হার",
        "খালি",
        "মাটি",
        "নগর",
        "পুর",
        "তলা",
    )

    cities = (
        "বরগুনা",
        "বরিশাল",
        "ভোলা",
        "বান্দরবান",
        "ব্রাহ্মণবাড়িয়া",
        "বাগেরহাট",
        "বগুড়া",
        "চাঁদপুর",
        "চট্টগ্রাম",
        "কুমিল্লা",
        "কক্সবাজার",
        "চুয়াডাঙ্গা",
        "ঢাকা",
        "দিনাজপুর",
        "ফরিদপুর",
        "ফেনী",
        "গাজীপুর",
        "গোপালগঞ্জ",
        "গাইবান্ধা",
        "হবিগঞ্জ",
        "ঝালকাঠি",
        "যশোর",
        "ঝিনাইদহ",
        "জামালপুর",
        "জয়পুরহাট",
        "খাগড়াছড়ি",
        "কিশোরগঞ্জ",
        "খুলনা",
        "কুষ্টিয়া",
        "কুড়িগ্রাম",
        "লক্ষ্মীপুর",
        "লালমনিরহাট",
        "মাদারীপুর",
        "মানিকগঞ্জ",
        "মুন্সীগঞ্জ",
        "মাগুরা",
        "মেহেরপুর",
        "ময়মনসিংহ",
        "মৌলভীবাজার",
        "নোয়াখালী",
        "নারায়ণগঞ্জ",
        "নরসিংদী",
        "নড়াইল",
        "নেত্রকোণা",
        "নওগাঁ",
        "নাটোর",
        "চাঁপাইনবাবগঞ্জ",
        "নীলফামারী",
        "পটুয়াখালী",
        "পিরোজপুর",
        "পাবনা",
        "পঞ্চগড়",
        "রাঙ্গামাটি",
        "রাজবাড়ী",
        "রাজশাহী",
        "রংপুর",
        "শরীয়তপুর",
        "সাতক্ষীরা",
        "শেরপুর",
        "সিরাজগঞ্জ",
        "সুনামগঞ্জ",
        "সিলেট",
        "টাঙ্গাইল",
        "ঠাকুরগাঁও",
    )

    countries = (
        "আফগানিস্তান",
        "আলবেনিয়া",
        "আলজেরিয়া",
        "আমেরিকান সামোয়া",
        "অ্যান্ডোরা",
        "অ্যাঙ্গোলা",
        "অ্যাঙ্গুইলা",
        "অ্যান্টার্কটিকা",
        "অ্যান্টিগুয়া ও বার্বুডা",
        "আর্জেন্টিনা",
        "আর্মেনিয়া",
        "আরুবা",
        "অস্ট্রেলিয়া",
        "অস্ট্রিয়া",
        "আজারবাইজান",
        "বাহামাস",
        "বাহরাইন",
        "বাংলাদেশ",
        "বার্বাডোস",
        "বেলারুশ",
        "বেলজিয়াম",
        "বেলিজ",
        "বেনিন",
        "বারমুডা",
        "ভুটান",
        "বলিভিয়া",
        "বসনিয়া-হার্জেগোভিনা",
        "বতসোয়ানা",
        "বাউবে দ্বীপ",
        "ব্রাজিল",
        "ব্রিটিশ ভারত মহাসাগরীয় অঞ্চল",
        "ব্রিটিশ ভার্জিন দ্বীপপুঞ্জ",
        "ব্রুনাই",
        "বুলগেরিয়া",
        "বুর্কিনা ফাসো",
        "বুরুন্ডি",
        "কম্বোডিয়া",
        "ক্যামেরুন",
        "কানাডা",
        "কেপ ভার্দে",
        "কেম্যান দ্বীপপুঞ্জ",
        "মধ্য আফ্রিকান প্রজাতন্ত্র",
        "চাদ",
        "চিলি",
        "চীন",
        "ক্রিস্টমাস দ্বীপ",
        "কোকোস দ্বীপপুঞ্জ",
        "কলাম্বিয়া",
        "কোমোরোস",
        "কঙ্গো প্রজাতন্ত্র",
        "কুক দ্বীপপুঞ্জ",
        "কোস্টারিকা",
        "আইভরি কোট",
        "ক্রোয়েশিয়া",
        "কিউবা",
        "সাইপ্রাস প্রজাতন্ত্র",
        "চেক প্রজাতন্ত্র",
        "ডেনমার্ক",
        "জিবুতি প্রজাতন্ত্র",
        "ডোমিনিকা",
        "ডোমিনিকান প্রজাতন্ত্র",
        "ইকুয়েডর",
        "মিশর",
        "এল সালভাদর",
        "নিরক্ষীয় গিনি",
        "ইরিত্রিয়া",
        "এস্তোনিয়া",
        "ইথিওপিয়া",
        "ফারো দ্বীপপুঞ্জ",
        "ফকল্যান্ড দ্বীপপুঞ্জ",
        "ফিজি প্রজাতন্ত্র",
        "ফিনল্যান্ড",
        "ফ্রান্স",
        "একটি দেশের নাম",
        "ফরাসি পলিনেশিয়া",
        "ফরাসি সুদূর দক্ষিণ দ্বীপপুঞ্জ",
        "গ্যাবন",
        "গাম্বিয়া",
        "জর্জিয়া",
        "জার্মানি",
        "ঘানা",
        "জিব্রাল্টার",
        "গ্রীস",
        "গ্রিনল্যান্ড",
        "গ্রেনাডা",
        "গুয়াডেলুপ",
        "গুয়াম",
        "গুয়াতেমালা",
        "গার্নসি",
        "গিনি",
        "গিনি-বিসাউ",
        "গিয়ানা",
        "হাইতি",
        "হার্ড আইল্যান্ড এবং ম্যাকডোনাল্ড দ্বীপপুঞ্জ",
        "ভ্যাটিকান সিটি",
        "হন্ডুরাস",
        "হংকং",
        "হাঙ্গেরি",
        "আইসল্যান্ড",
        "ভারত",
        "ইন্দোনেশিয়া",
        "ইরান",
        "ইরাক",
        "আপনি উত্তর দিবেন না",
        "আইল অফ ম্যান",
        "ইসরায়েল",
        "ইতালি",
        "জ্যামাইকা",
        "জাপান",
        "জার্সি",
        "জর্ডান",
        "কাজাখস্তান",
        "কেনিয়া",
        "কিরিবাতি",
        "কোরিয়া",
        "কোরিয়া",
        "কুয়েত",
        "কিরগিজস্তান প্রজাতন্ত্র",
        "পিপলস ডেমোক্রেটিক রিপাবলিক অফ লাওস",
        "লাটভিয়া",
        "লেবানন",
        "লেসোথো",
        "লাইবেরিয়া",
        "লিবিয়া",
        "লিচেনস্টাইন",
        "লিথুয়ানিয়া",
        "লাক্সেমবার্গ",
        "ম্যাকাও",
        "উত্তর মেসিডোনিয়া প্রজাতন্ত্র",
        "মাদাগাস্কার",
        "মালাউই",
        "মালয়েশিয়া",
        "মালদ্বীপ",
        "মালি",
        "মাল্টা প্রজাতন্ত্র",
        "মার্শাল দ্বীপপুঞ্জ",
        "মার্টিনিক",
        "ইসলামী প্রজাতন্ত্র মৌরিতানিয়া",
        "মরিশাস",
        "মায়োট",
        "মেক্সিকো",
        "মাইক্রোনেশিয়ার ফেডারেটেড স্টেটস",
        "মোল্দোভা প্রজাতন্ত্র",
        "মোনাকোর রাজত্ব",
        "মঙ্গোলিয়া",
        "মন্টিনিগ্রো প্রজাতন্ত্র",
        "মন্টসেরাট",
        "মরক্কো",
        "মোজাম্বিক",
        "মিয়ানমার",
        "নামিবিয়া",
        "নাউরু",
        "নেপাল",
        "নেদারল্যান্ডস এন্টিলস",
        "নেদারল্যান্ডস",
        "নতুন ক্যালেডোনিয়া",
        "নিউজিল্যান্ড",
        "নিকারাগুয়া",
        "নাইজার",
        "নাইজেরিয়া",
        "সুন্দর",
        "নরফোক দ্বীপ",
        "উত্তর মারিয়ানা দ্বীপপুঞ্জ",
        "নরওয়ে",
        "ওমান",
        "পাকিস্তান",
        "পালাউ",
        "ফিলিস্তিন অঞ্চল",
        "পানামা",
        "পাপুয়া নিউ গিনি",
        "প্যারাগুয়ে",
        "পেরু",
        "ফিলিপাইন",
        "পিটকের্ন দ্বীপপুঞ্জ",
        "পোল্যান্ড",
        "পর্তুগাল",
        "পুয়ের্তো রিকো",
        "কাতার",
        "পুনর্মিলন",
        "রোমানিয়া",
        "রাশিয়া",
        "রুয়ান্ডা",
        "সেন্ট বার্থেলেমি",
        "সেন্ট হেলেনা",
        "সেন্ট কিটস ও নেভিস",
        "সেন্ট লুসিয়া",
        "সেন্ট মার্টিন",
        "সেন্ট পিয়ের এবং মিকেলন",
        "সেন্ট ভিনসেন্ট ও গ্রেনাডাইন দ্বীপপুঞ্জ",
        "সামোয়া",
        "সান মারিনো",
        "স্যান্টোম প্রিন্সিপ",
        "সৌদি আরব",
        "সেনেগাল",
        "সার্বিয়া",
        "সেশেলস",
        "সিয়েরা লিওন",
        "সিঙ্গাপুর",
        "স্লোভাকিয়া",
        "স্লোভেনিয়া",
        "সলোমান দ্বীপপুঞ্জ",
        "সোমালিয়া",
        "দক্ষিণ আফ্রিকা প্রজাতন্ত্র",
        "দক্ষিণ জর্জিয়া এবং দক্ষিণ স্যান্ডউইচ দ্বীপপুঞ্জ",
        "স্পেন",
        "শ্রীলংকা",
        "সুদান",
        "সুরিনাম",
        "স্বালবার্ড এবং জানমায়েন দ্বীপপুঞ্জ",
        "সোয়াজিল্যান্ডের রাজ্য",
        "সুইডেন",
        "সুইজারল্যান্ড",
        "সিরিয়া",
        "তাইওয়ান",
        "তাজিকিস্তান প্রজাতন্ত্র",
        "তানজানিয়া",
        "থাইল্যান্ড",
        "পূর্ব তিমুর",
        "যাও",
        "টোকেলাউ",
        "টোঙ্গা",
        "ত্রিনিদাদ ও টোবাগো প্রজাতন্ত্র",
        "তিউনিসিয়া",
        "তুরস্ক",
        "তুর্কমেনিস্তান",
        "টার্কস্ ও কেইকোস দ্বীপপুঞ্জ",
        "টুভালু",
        "উগান্ডা",
        "ইউক্রেন",
        "সংযুক্ত আরব আমিরাত",
        "ইংল্যান্ড",
        "মার্কিন যুক্তরাষ্ট্র",
        "ইউএস মাইনর আউটলি আইল্যান্ড",
        "আমেরিকান ভার্জিন আইল্যান্ডস",
        "উরুগুয়ে",
        "উজবেকিস্তান",
        "ভানুয়াতু",
        "ভেনিজুয়েলা",
        "ভিয়েতনাম",
        "ওয়ালিস এবং ফুটুনা",
        "পশ্চিম সাহারা",
        "ইয়েমেন",
        "জাম্বিয়া",
        "জিম্বাবুয়ে",
    )

    secondary_address_formats = (
        "ফ্ল্যাট %",
        "ফ্ল্যাট %#",
        "ষ্টুডিও %",
        "ষ্টুডিও %#",
        "অ্যাপার্টমেন্ট %",
        "অ্যাপার্টমেন্ট %#",
    )

    street_suffixes = (
        "এভিনিউ",
        "সেন্টার",
        "চত্বর",
        "গলি",
        "ঘাট",
        "কর্নার",
        "লেন",
        "মহাসড়ক",
        "মহল্লা",
        "মোড়",
        "পাড়া",
        "পার্ক",
        "প্লাজা",
        "রাস্তা",
        "রোড",
        "সড়ক",
        "স্টেশন",
        "স্ট্যান্ড",
    )

    postcode_formats = ("%###",)
    street_name_formats = (
        "{{area_name}}{{street_suffix}}",
        "{{city_prefix}} {{area_name}}{{street_suffix}}",
        "{{city_prefix}} {{area_name}}{{city_suffix}}",
        "{{area_name}}{{city_suffix}}",
        "{{area_name}}{{city_suffix}} {{street_suffix}}",
        "{{city_prefix}} {{area_name}}{{city_suffix}} {{street_suffix}}",
    )
    street_address_formats = (
        "{{building_name}} {{building_number}}, {{street_name}}",
        "{{secondary_address}}, {{building_name}} {{building_number}}, {{street_name}}",
    )
    town_formats = ("{{area_name}}{{city_suffix}}",)
    address_formats = ("{{street_address}}, {{town}}, {{city}}, {{postcode}}",)

    def administrative_unit(self) -> str:
        """
        :example: 'ঢাকা'
        """
        return self.random_element(self.cities)

    def area_name(self) -> str:
        """
        :example: 'উজির'
        """
        return self.random_element(self.area_names)

    def building_name(self) -> str:
        """
        :example: 'বাড়ী নং'
        """
        return self.random_element(self.building_names)

    def building_number(self) -> str:
        """
        :example: '791' to '৭৯১'
        """
        return translate_to_bengali_digits(self.numerify(self.random_element(self.building_number_formats)))

    def city_prefix(self) -> str:
        """
        :example: 'উত্তর'
        """
        return self.random_element(self.city_prefixes)

    def city(self) -> str:
        """
        :example: 'ঢাকা'
        """
        return self.random_element(self.cities)

    def postcode(self) -> str:
        """
        See
        https://bdpost.portal.gov.bd/site/page/6aaeabe4-479b-4e5a-a671-e9e5b994bf9a
        """
        return translate_to_bengali_digits(self.numerify(self.random_element(self.postcode_formats)))

    def secondary_address(self) -> str:
        """
        As the generated string format is a Bengali word but English number so splitting the value by space
        and then convert the English number to Bengali number and concat with generated Bengali word
        and return
        : example : 'অ্যাপার্টমেন্ট 14' to 'অ্যাপার্টমেন্ট ১৪'
        """
        value = self.bothify(self.random_element(self.secondary_address_formats))
        word_list = value.split(" ")
        return word_list[0] + " " + translate_to_bengali_digits(word_list[1])

    def town(self) -> str:
        """
        :example: 'নবাব'
        """
        pattern: str = self.random_element(self.town_formats)
        return self.generator.parse(pattern)



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    DAY_NAMES = {
        "0": "Ravivar",
        "1": "Somvar",
        "2": "Mangalvar",
        "3": "Budhvar",
        "4": "Guruvar",
        "5": "Shukravar",
        "6": "Shanivar",
    }

    DAY_NAMES_IN_GUJARATI = {
        "0": "રવિવાર",
        "1": "સોમવાર",
        "2": "મંગળવાર",
        "3": "બુધવાર",
        "4": "ગુરુવાર",
        "5": "શુક્રવાર",
        "6": "શનિવાર",
    }

    MONTH_NAMES = {
        "01": "Kartak",
        "02": "Magshar",
        "03": "Posh",
        "04": "Maha",
        "05": "Fagan",
        "06": "Chaitra",
        "07": "Vaishakh",
        "08": "Jeth",
        "09": "Ashadh",
        "10": "Shravan",
        "11": "Bhadarvo",
        "12": "Aaso",
    }

    MONTH_NAMES_IN_GUJARATI = {
        "01": "કારતક",
        "02": "માગશર",
        "03": "પોષ",
        "04": "મહા",
        "05": "ફાગણ",
        "06": "ચૈત્ર",
        "07": "વૈશાખ",
        "08": "જેઠ",
        "09": "અષાઢ",
        "10": "શ્રાવણ",
        "11": "ભાદરવો",
        "12": "આસો",
    }

    def day_of_week(self) -> str:
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self) -> str:
        month = self.month()
        return self.MONTH_NAMES[month]

    def day_of_week_in_guj(self) -> str:
        """Returns day of the week in `Gujarati`"""
        day = self.date("%w")
        return self.DAY_NAMES_IN_GUJARATI[day]

    def month_name_in_guj(self) -> str:
        """Returns month name in `Gujarati`"""
        month = self.month()
        return self.MONTH_NAMES_IN_GUJARATI[month]

    def month_in_guj(self) -> str:
        """Returns month name in `Gujarati`"""
        return self.month_name_in_guj()



from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``vi_VN`` locale.

    Word list is based on common Vietnamese words and phrases.
    # Source : https://vi.wikipedia.org/wiki/Ng%E1%BB%AF_ph%C3%A1p_ti%E1%BA%BFng_Vi%E1%BB%87t
    """

    word_list = (
        "cái",
        "đó",
        "là",
        "và",
        "có",
        "như",
        "một",
        "để",
        "cũng",
        "với",
        "cho",
        "trong",
        "tôi",
        "của",
        "người",
        "không",
        "sẽ",
        "đã",
        "này",
        "theo",
        "làm",
        "nơi",
        "đang",
        "nếu",
        "bạn",
        "được",
        "khi",
        "thì",
        "về",
        "mà",
        "cũng",
        "nào",
        "của",
        "nhưng",
        "vì",
        "rất",
        "tại",
        "tại",
        "thế",
        "để",
        "giữa",
        "với",
        "cách",
        "từ",
        "lớn",
        "có",
        "vài",
        "hơn",
        "vẫn",
        "dưới",
        "đi",
        "đến",
        "vậy",
        "điều",
        "hoặc",
        "chỉ",
        "hơn",
        "khiến",
        "giống",
        "sau",
        "trong",
        "đúng",
        "của",
        "mỗi",
        "như",
        "bên",
        "để",
        "chưa",
        "như",
        "thay",
        "như",
        "các",
        "tự",
        "số",
        "từng",
        "nhiều",
        "gần",
        "từ",
    )

    parts_of_speech: Dict[str, tuple] = {
        "verb": (
            "là",
            "có",
            "làm",
            "đi",
            "nói",
            "thấy",
            "nghe",
            "đọc",
            "viết",
            "muốn",
            "đi",
            "ngồi",
            "uống",
            "ăn",
            "học",
            "chơi",
            "nhìn",
            "được",
            "tìm",
            "đặt",
            "giúp",
            "hỏi",
            "giải",
            "mua",
            "bán",
            "nói",
        ),
        "noun": (
            "người",
            "sách",
            "máy",
            "bàn",
            "ghế",
            "cửa",
            "nhà",
            "bút",
            "xe",
            "điện thoại",
            "bánh",
            "cà phê",
            "nước",
            "trường",
            "chúng tôi",
            "học sinh",
            "giáo viên",
            "bố",
            "mẹ",
            "em",
            "anh",
            "chị",
        ),
        "adverb": (
            "thực sự",
            "rất",
            "nhanh",
            "chậm",
            "tốt",
            "xấu",
            "đúng",
            "sai",
            "vui",
            "buồn",
            "mới",
            "cũ",
            "dễ",
            "khó",
            "gần",
            "xa",
            "hơn",
            "vẫn",
            "đã",
            "mới",
        ),
        "adjective": (
            "đẹp",
            "xấu",
            "tốt",
            "xấu",
            "to",
            "nhỏ",
            "ngọt",
            "chua",
            "mặn",
            "nhanh",
            "chậm",
            "đầu",
            "cuối",
            "mới",
            "cũ",
            "dễ",
            "khó",
            "hơi",
            "vui",
            "buồn",
            "mạnh",
            "yếu",
        ),
    }



from ... import ElementsType
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source:
    # https://www.ilo.org/public/spanish/bureau/stat/isco/docs/struct08.xls
    jobs: ElementsType[str] = (
        "Abogado",
        "Acarreador de agua",
        "Recolector de leña",
        "Ayudante de cámara",
        "Actor",
        "Administrador de sistemas",
        "Agente de administración tributaria",
        "Agente de aduanas",
        "Inspector de fronteras",
        "Agente de bolsa",
        "Agente de compras",
        "Consignatario",
        "Agente de empleo",
        "Agente de seguros",
        "Agente de servicios de expedición de licencias y permisos",
        "Agente de servicios de seguridad social",
        "Agente inmobiliario",
        "Agricultor",
        "Agrónomo",
        "Albañil",
        "Alfarero",
        "Analista de gestión y organización",
        "Analista de sistemas",
        "Analista financiero",
        "Aparejador",
        "Empalmador de cables",
        "Curtidor",
        "Apicultor",
        "Sericultor",
        "Archivista",
        "Curador de museos",
        "Arquitecto",
        "Paisajista",
        "Artesano",
        "Artista plástico",
        "Asesor financiero y en inversiones",
        "Asesor de inversiones",
        "Asistente de venta",
        "Astrólogo",
        "Adivinador",
        "Deportista",
        "Audiólogo",
        "Escritor",
        "Auxiliar de maestro",
        "Auxiliar de servicio de abordo",
        "Auxiliar laico de las religión",
        "Avicultor",
        "Ayudante de ambulancia",
        "Ayudante de cocina",
        "Bailarín",
        "Coreógrafo",
        "Barnizador",
        "Barrendero",
        "Bibliotecarios",
        "Focumentalista",
        "Biólogo",
        "Botánico",
        "Zoólogo",
        "Zoólogo",
        "Bombero",
        "Buzo",
        "Cajero de banco",
        "Cajero",
        "Tipógrafo",
        "Camarero de barra",
        "Camarero de mesa",
        "Capitán decubierta",
        "Oficial de cubierta",
        "Carnicero",
        "Pescadero",
        "Carpintero",
        "Cartógrafo",
        "Agrimensor",
        "Catador de alimentos y bebidas",
        "Catador de bebidas",
        "Cazador",
        "Tramper",
        "Chapista",
        "Calderero",
        "Chef",
        "Clasificador de desechos",
        "Clasificador de productos",
        "Cobrador",
        "Cocinero",
        "Cocinero de comidas rápidas",
        "Codificador de datos",
        "Corrector de pruebas de imprenta",
        "Comerciante de tiendas",
        "Conductor de autobús",
        "Conductor de tranvía",
        "Conductor de automóviles",
        "Conductor de taxis",
        "Conductor de camiones pesados",
        "Conductor de motocicletas",
        "Conductor de vehículos accionados a pedal o a brazo",
        "Conductor de vehículos y máquinas de tracción animal",
        "Conserje",
        "Constructor de casas",
        "Contable",
        "Controlador de instalaciones de procesamiento de productos químicos",
        "Controlador de procesos",
        "Controlador de tráfico aéreo",
        "Costurero",
        "Bordador",
        "Criador de ganado",
        "Cristalero",
        "Cuidador de animales",
        "Cuidador de niños",
        "Declarante de aduana",
        "Gestor de aduana",
        "Delineante",
        "Dibujante técnico",
        "Demostrador de tiendas",
        "Dentista",
        "Ayudante de odontología",
        "Desarrollador de software",
        "Desarrollador Web y multimedia",
        "Nutricionista",
        "Dinamitero",
        "Director de servicios de bienestar social",
        "Director de cine",
        "Director de teatro",
        "Director de empresas de abastecimiento, distribución y afines",
        "Director de empresas de construcción",
        "Director de explotaciones de minería",
        "Director de industrias manufactureras",
        "Director de investigación y desarrollo",
        "Director de políticas y planificación",
        "Director de producción agropecuaria y silvicultura",
        "Director de producción de piscicultura y pesca",
        "Director de publicidad y relaciones públicas",
        "Director de recursos humanos",
        "Director de servicios de cuidado de las personas de edad",
        "Director de servicios de cuidados infantiles",
        "Director de servicios de educación",
        "Director de servicios de salud",
        "Director de servicios de tecnología de la información y las comunicaciones",
        "Director de ventas y comercialización",
        "Director financiero",
        "Gerente general",
        "Diseñador de productos",
        "Diseñador de prendas",
        "Diseñador gráfico",
        "Diseñador multimedia",
        "Diseñador de bases de datos",
        "Administrador de bases de datos",
        "Diseñador de interior",
        "Decorador de interior",
        "Ebanista",
        "Economista",
        "Ecónomo y mayordomos domésticos",
        "Mayordomo doméstico",
        "Educador para necesidades especiales",
        "Electricista de obras",
        "Electrotécnico",
        "Empacador manual",
        "Empleado de agencia de viajes",
        "Empleado de archivos",
        "Empleado de biblioteca",
        "Empleado de centro de llamadas",
        "Empleado de contabilidad y cálculo de costos",
        "Empleado de control de abastecimientos e inventario",
        "Empleado de servicios de apoyo a la producción",
        "Empleado de servicios de correos",
        "Empleado de servicios de transporte",
        "Empleado de servicios estadísticos, financieros y de seguros",
        "Empleado de ventanillas de informaciones",
        "Empleado del servicio de personal",
        "Empleado encargado de las nóminas",
        "Encuadernador",
        "Ensamblador de equipos eléctricos",
        "Ensamblador de equipos electrónicos",
        "Ensamblador de maquinaria mecánica",
        "Entrenador deportivo",
        "Árbitro deportivo",
        "Entrevistador de encuestas",
        "Entrevistador de investigaciones de mercados",
        "Escribiente público",
        "Especialista en formación del personal",
        "Especialista en métodos pedagógicos",
        "Especialista en políticas de administración",
        "Especialista en políticas y servicios de personal",
        "Especialista en tratamientos de belleza",
        "Expendedor de gasolineras",
        "Fabricante de instrumentos musicales",
        "Afinador de instrumentos musicales",
        "Farmacéutico",
        "Filósofo",
        "Historiador",
        "Especialista en ciencias políticas",
        "Físico",
        "Astrónomos",
        "Fisioterapeuta",
        "Fontanero",
        "Fotógrafo",
        "Fumigador",
        "Controlador de plagas y malas hierbas",
        "Geólogo",
        "Ggeofísico",
        "Gerente de centros deportivos, de esparcimiento y culturales",
        "Gerente de comercios al por mayor y al por menor",
        "Gerente de hoteles o restaurantes",
        "Gerente de sucursales de bancos, de servicios financieros y de seguros",
        "Grabador de datos",
        "Guardafrenos",
        "Guardagujas",
        "Agente de maniobras",
        "Guardián de prisión",
        "Guardia de protección",
        "Guía de turismo",
        "Herramentista",
        "Herrero",
        "Gorjadore",
        "Impresor",
        "Ingeniero civil",
        "Ingeniero de minas",
        "Ingeniero metalúrgico",
        "Ingeniero electricista",
        "Ingeniero electrónico",
        "Ingeniero en telecomunicaciones",
        "Ingeniero industrial",
        "Ingeniero mecánico",
        "Ingeniero medioambiental",
        "Ingeniero químico",
        "Inspector de la salud laboral",
        "Inspector medioambiental y afines",
        "Inspector de policía",
        "Detective",
        "Instalador de material aislante y de insonorización",
        "Instalador y reparador de líneas eléctricas",
        "Instalador y reparador en tecnología de la información y las comunicaciones",
        "Instructor de autoescuela",
        "Instructor de educación física y actividades recreativas",
        "Instructor en tecnologías de la información",
        "Jefe de pequeñas poblaciones",
        "Joyero",
        "Orfebre",
        "Platero",
        "Juez",
        "Lavador de vehículos",
        "Lavador de ventanas",
        "Lavandero",
        "Planchador manuales",
        "Limpiador de fachadas",
        "Deshollinador",
        "Limpiador y asistente de oficinas, hoteles y otros establecimientos",
        "Limpiador y asistente doméstico",
        "Locutor de radio",
        "Locutor de televisión",
        "Maestro de enseñanza primaria",
        "Maestro preescolar",
        "Mampostero",
        "Labrante",
        "Tronzador",
        "Grabador de piedra",
        "Maquinista de locomotoras",
        "Marinero de cubierta",
        "Matemático",
        "Actuario",
        "Estadístico",
        "Mecánico y ajustador electricista",
        "Mecánico y reparador de instrumentos de precisión",
        "Mecánico y reparador de máquinas agrícolas e industriales",
        "Mecánico y reparador de motores de avión",
        "Mecánico y reparador de vehículos de motor",
        "Mecánico y reparador en electrónica",
        "Mecánico-montador de instalaciones de refrigeración y climatización",
        "Médico especialista",
        "Médico general",
        "Mensajero",
        "Mandader",
        "Maleter",
        "Repartidor",
        "Meteorólogo",
        "Minero",
        "Operador de instalaciones mineras",
        "Modelo de moda, arte y publicidad",
        "Moldeador y machero",
        "Montador de estructuras metálicas",
        "Músico",
        "Cantante",
        "Compositor",
        "Oficial de las fuerzas armadas",
        "Oficial de préstamos y créditos",
        "Oficial maquinistas en navegación",
        "Oficinista general",
        "Operador de autoelevadoras",
        "Operador de grúas y aparatos elevadores",
        "Operador de incineradores, instalaciones de tratamiento de agua",
        "Operador de instalaciones de tratamiento de agua",
        "Operador de instalaciones de procesamiento de la madera",
        "Operador de instalaciones de procesamiento de metales",
        "Operador de instalaciones de procesamiento de minerales y rocas",
        "Operador de instalaciones de producción de energía",
        "Operador de instalaciones de refinación de petróleo y gas natural",
        "Operador de instalaciones de vidriería y cerámica",
        "Operador de instalaciones para la preparación de pasta para papel y papel",
        "Operador de maquinaria agrícola y forestal móvil",
        "Operador de máquinas de blanqueamiento, teñido y limpieza de tejidos",
        "Operador de máquinas de coser",
        "Operador de máquinas de embalaje, embotellamiento y etiquetado ",
        "Operador de máquinas de movimiento de tierras",
        "Operador de máquinas de preparación de fibras, hilado y devanado",
        "Operador de máquinas de procesamiento de texto y mecanógrafos",
        "Operador de máquinas de tratamiento de pieles y cueros",
        "Operador de máquinas de vapor y calderas",
        "Operador de máquinas lavarropas",
        "Operador de máquinas para elaborar alimentos y productos afines",
        "Operador de máquinas para fabricar cemento y otros productos minerales",
        "Operador de máquinas para fabricar productos de caucho",
        "Operador de máquinas para fabricar productos de material plástico",
        "Operador de máquinas para fabricar productos de papel",
        "Operador de máquinas para fabricar productos fotográficos",
        "Operador de máquinas para la fabricación de calzado",
        "Operador de máquinas pulidoras, galvanizadoras y recubridoras de metales ",
        "Operador de plantas y máquinas de productos químicos",
        "Operador de telar y otras máquinas tejedoras",
        "Operario de la conservación de frutas, legumbres y verduras",
        "Operario de la elaboración de productos lácteos",
        "Operario del tratamiento de la madera",
        "Operario en cemento armado y enfoscador",
        "Optometrista",
        "Organizador de conferencias y eventos",
        "Personal de limpieza",
        "Miembro de las fuerzas armadas",
        "Profesional de nivel medio en actividades culturales y artísticas",
        "Profesor de artes",
        "Profesor de idiomas",
        "Profesor de música",
        "Panaderos, pasteleros y confiteros",
        "Parquetero y colocador de suelos",
        "Patronista y cortador de tela",
        "Peluqueros",
        "Peón de carga",
        "Peón de explotaciones agrícolas",
        "Peón de explotaciones de cultivos mixtos y ganaderos",
        "Peón de explotaciones ganaderas",
        "Peón de jardinería y horticultura",
        "Peón de la construcción de edificios",
        "Peón de minas y canteras",
        "Peón de obras públicas y mantenimiento",
        "Peón de pesca y acuicultura",
        "Peón forestales",
        "Perforador y sondista de pozos",
        "Periodista",
        "Personal de pompas fúnebres y embalsamador",
        "Personal directivo de la administración pública",
        "Personas que realizan trabajos varios",
        "Pescador, cazador, tramperos y recolector de subsistencia",
        "Pescador de agua dulce y en aguas costeras",
        "Pescador de alta mar",
        "Piloto de aviación",
        "Pintor y empapelador",
        "Policías",
        "Practicante paramédico",
        "Practicante y asistente médico",
        "Preparador y elaborador de tabaco y sus productos",
        "Prestamista",
        "Productor y trabajador calificado de explotaciones agropecuarias mixtas",
        "Profesional de enfermería",
        "Profesional de la protección medioambiental",
        "Profesional de la publicidad y la comercialización",
        "Profesional de la salud y la higiene laboral y ambiental",
        "Profesional de medicina",
        "Profesional de medicina alternativa",
        "Profesional de nivel medio de enfermería",
        "Profesional de nivel medio de medicina tradicional y alternativa",
        "Profesional de nivel medio de medicina alternativa",
        "Profesional de nivel medio de partería",
        "Profesional de nivel medio de servicios estadísticos o matemáticos",
        "Profesional de nivel medio del derecho y servicios legales",
        "Profesional de partería",
        "Profesional de relaciones públicas",
        "Profesional de ventas de tecnología de la información y las comunicaciones",
        "Profesional de ventas técnicas y médicas",
        "Profesional del trabajo social",
        "Profesional en redes de computadores",
        "Profesional religioso",
        "Profesor de enseñanza secundaria",
        "Profesor de formación profesional",
        "Profesor de universidades y de la enseñanza superior",
        "Programador de aplicaciones",
        "Psicólogo",
        "Pulidor de metales y afilador de herramientas",
        "Químico",
        "Recepcionista de hoteles",
        "Recepcionista",
        "Receptor de apuestas",
        "Recolector de basura y material reciclable",
        "Recolector de dinero en aparatos de venta automática y lector de medidores",
        "Redactor de carteles, pintor decorativos y grabador",
        "Regulador y operador de máquinas de labrar madera",
        "Regulador y operador de máquinas y herramientas",
        "Reparador de bicicletas",
        "Reponedor de estanterías",
        "Representante comercial",
        "Revisor y cobrador de los transportes públicos",
        "Revocador",
        "Modisto",
        "Peletero",
        "Sombrerero",
        "Secretario administrativo",
        "Secretario ejecutivo",
        "Secretario (general)",
        "Secretario jurídicos",
        "Secretario médicos",
        "Sociólogo",
        "Antropólogo",
        "Soldador y oxicortador",
        "Soplador de vidrio",
        "Modelador de vidrio",
        "Laminador de vidrio",
        "Cortador de vidrio",
        "Pulidor de vidrio",
        "Suboficial de las fuerzas armadas",
        "Supervisor de industria manufacturera",
        "Supervisor de la construcción",
        "Supervisor de mantenimiento y limpieza en oficinas, hoteles y otros establecimientos",
        "Supervisor de secretaría",
        "Supervisor de tiendas y almacenes",
        "Supervisor en ingeniería de minas",
        "Tapicero",
        "Colchonero",
        "Tasador",
        "Techador",
        "Técnico agropecuario",
        "Técnico de telecomunicaciones",
        "Técnico de la Web",
        "Técnico de laboratorio médico",
        "Técnico de prótesis médicas y dentales",
        "Técnico de radiodifusión y grabación audio visual",
        "Técnico en aparatos de diagnóstico y tratamiento médico",
        "Técnico en asistencia al usuario de tecnología de la información y las comunicaciones",
        "Técnico en ciencias biológicas",
        "Técnico en ciencias físicas y químicas",
        "Técnico en documentación sanitaria",
        "Técnico en electrónica",
        "Técnico en galerías de arte, museos y bibliotecas",
        "Técnico en ingeniería civil",
        "Técnico en ingeniería de minas y metalurgia",
        "Técnico en ingeniería mecánica",
        "Técnico en operaciones de tecnología de la información y las comunicaciones",
        "Técnico en optometría y ópticos",
        "Técnico en química industrial",
        "Técnico en redes y sistemas de computadores",
        "Técnico en seguridad aeronáutica",
        "Técnico forestal",
        "Asistente farmacéutico",
        "Asistente fisioterapeuta",
        "Asistente veterinario",
        "Telefonista",
        "Tenedor de libros",
        "Trabajador agrícola de subsistencia",
        "Trabajador agropecuario de subsistencia",
        "Trabajador ambulante de servicios",
        "Trabajador comunitario de la salud",
        "Trabajador de explotaciones de acuicultura",
        "Trabajador de cuidados personales a domicilio",
        "Trabajador de cuidados personales en instituciones",
        "Trabajador forestal calificado",
        "Trabajador pecuario de subsistencia",
        "Trabajador social de nivel medio",
        "Traductor e intérprete",
        "Lingüista",
        "Urbanistas e ingenieros de tránsito",
        "Vendedor ambulantes de productos comestibles",
        "Vendedor ambulantes (excluyendo de comida)",
        "Vendedor de comidas al mostrador",
        "Vendedor de quioscos y de puestos de mercado",
        "Vendedor por teléfono",
        "Vendedor puerta a puerta",
        "Veterinario",
        "Zapatero",
        "Miembro del poder legislativo",
    )



from .. import BaseProvider

localized = False


class Provider(BaseProvider):
    """Provider for weather and meteorological data."""

    # Weather conditions
    weather_conditions = [
        "Sunny", "Partly Cloudy", "Cloudy", "Overcast", "Clear",
        "Rainy", "Light Rain", "Heavy Rain", "Drizzle", "Showers",
        "Thunderstorm", "Lightning", "Stormy", "Snowy", "Light Snow",
        "Heavy Snow", "Blizzard", "Sleet", "Freezing Rain", "Hail",
        "Foggy", "Misty", "Hazy", "Windy", "Breezy", "Calm",
        "Hot", "Warm", "Cool", "Cold", "Freezing", "Humid", "Dry"
    ]

    # Detailed weather descriptions
    weather_descriptions = [
        "Clear skies with plenty of sunshine",
        "Partly cloudy with occasional sun",
        "Mostly cloudy throughout the day",
        "Overcast with gray skies",
        "Light rain expected in the afternoon",
        "Heavy rain with possible flooding",
        "Scattered showers throughout the day",
        "Thunderstorms likely in the evening",
        "Light snow flurries expected",
        "Heavy snowfall with accumulation",
        "Foggy conditions reducing visibility",
        "Windy with gusts up to 40 mph",
        "Humid conditions with possible rain",
        "Dry and sunny all day",
        "Partly cloudy with a chance of rain",
        "Clear and cold overnight",
        "Warm and sunny with light breeze",
        "Cool and breezy with clouds",
        "Hot and humid with afternoon storms",
        "Freezing temperatures with ice"
    ]

    # Precipitation types
    precipitation_types = [
        "No Precipitation", "Light Rain", "Moderate Rain", "Heavy Rain",
        "Light Snow", "Moderate Snow", "Heavy Snow", "Sleet",
        "Freezing Rain", "Hail", "Drizzle", "Showers", "Flurries"
    ]

    # Cloud cover levels
    cloud_cover_levels = [
        "Clear", "Mostly Clear", "Partly Cloudy", "Mostly Cloudy",
        "Cloudy", "Overcast"
    ]

    # Wind directions
    wind_directions = [
        "N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE",
        "S", "SSW", "SW", "WSW", "W", "WNW", "NW", "NNW",
        "North", "Northeast", "East", "Southeast",
        "South", "Southwest", "West", "Northwest"
    ]

    # Air quality levels
    air_quality_levels = [
        "Good", "Moderate", "Unhealthy for Sensitive Groups",
        "Unhealthy", "Very Unhealthy", "Hazardous"
    ]

    # UV index levels
    uv_index_levels = [
        "Low", "Moderate", "High", "Very High", "Extreme"
    ]

    # Weather alerts
    weather_alerts = [
        "No Alerts", "Heat Advisory", "Wind Advisory", "Flood Watch",
        "Flood Warning", "Severe Thunderstorm Watch", "Severe Thunderstorm Warning",
        "Tornado Watch", "Tornado Warning", "Winter Storm Watch",
        "Winter Storm Warning", "Blizzard Warning", "Ice Storm Warning",
        "Hurricane Watch", "Hurricane Warning", "Tropical Storm Watch",
        "Tropical Storm Warning", "High Wind Warning", "Freeze Warning"
    ]

    # Seasons
    seasons = ["Spring", "Summer", "Fall", "Autumn", "Winter"]

    # Moon phases
    moon_phases = [
        "New Moon", "Waxing Crescent", "First Quarter", "Waxing Gibbous",
        "Full Moon", "Waning Gibbous", "Last Quarter", "Waning Crescent"
    ]

    def weather(self) -> str:
        """
        Generate a random weather condition.
        
        :example: 'Sunny'
        """
        return self.random_element(self.weather_conditions)

    def weather_description(self) -> str:
        """
        Generate a random detailed weather description.
        
        :example: 'Clear skies with plenty of sunshine'
        """
        return self.random_element(self.weather_descriptions)

    def temperature(self, min_temp: int = -20, max_temp: int = 110, unit: str = "F") -> str:
        """
        Generate a random temperature.
        
        :param min_temp: Minimum temperature (default: -20)
        :param max_temp: Maximum temperature (default: 110)
        :param unit: Temperature unit 'F' or 'C' (default: 'F')
        :example: '72°F'
        """
        temp = self.random_int(min_temp, max_temp)
        return f"{temp}°{unit}"

    def temperature_celsius(self, min_temp: int = -30, max_temp: int = 45) -> str:
        """
        Generate a random temperature in Celsius.
        
        :param min_temp: Minimum temperature (default: -30)
        :param max_temp: Maximum temperature (default: 45)
        :example: '22°C'
        """
        return self.temperature(min_temp, max_temp, "C")

    def temperature_fahrenheit(self, min_temp: int = -20, max_temp: int = 110) -> str:
        """
        Generate a random temperature in Fahrenheit.
        
        :param min_temp: Minimum temperature (default: -20)
        :param max_temp: Maximum temperature (default: 110)
        :example: '72°F'
        """
        return self.temperature(min_temp, max_temp, "F")

    def wind_speed(self, min_speed: int = 0, max_speed: int = 60, unit: str = "mph") -> str:
        """
        Generate a random wind speed.
        
        :param min_speed: Minimum speed (default: 0)
        :param max_speed: Maximum speed (default: 60)
        :param unit: Speed unit 'mph' or 'kph' (default: 'mph')
        :example: '15 mph'
        """
        speed = self.random_int(min_speed, max_speed)
        return f"{speed} {unit}"

    def wind_direction(self) -> str:
        """
        Generate a random wind direction.
        
        :example: 'NW'
        """
        return self.random_element(self.wind_directions)

    def humidity(self, min_humidity: int = 20, max_humidity: int = 100) -> str:
        """
        Generate a random humidity percentage.
        
        :param min_humidity: Minimum humidity (default: 20)
        :param max_humidity: Maximum humidity (default: 100)
        :example: '65%'
        """
        humidity = self.random_int(min_humidity, max_humidity)
        return f"{humidity}%"

    def precipitation(self) -> str:
        """
        Generate a random precipitation type.
        
        :example: 'Light Rain'
        """
        return self.random_element(self.precipitation_types)

    def precipitation_amount(self, min_amount: float = 0.0, max_amount: float = 5.0, unit: str = "in") -> str:
        """
        Generate a random precipitation amount.
        
        :param min_amount: Minimum amount (default: 0.0)
        :param max_amount: Maximum amount (default: 5.0)
        :param unit: Unit 'in' or 'mm' (default: 'in')
        :example: '0.5 in'
        """
        amount = self.random_int(int(min_amount * 10), int(max_amount * 10)) / 10
        return f"{amount} {unit}"

    def cloud_cover(self) -> str:
        """
        Generate a random cloud cover level.
        
        :example: 'Partly Cloudy'
        """
        return self.random_element(self.cloud_cover_levels)

    def visibility(self, min_miles: int = 0, max_miles: int = 10, unit: str = "miles") -> str:
        """
        Generate a random visibility distance.
        
        :param min_miles: Minimum visibility (default: 0)
        :param max_miles: Maximum visibility (default: 10)
        :param unit: Unit 'miles' or 'km' (default: 'miles')
        :example: '10 miles'
        """
        distance = self.random_int(min_miles, max_miles)
        return f"{distance} {unit}"

    def pressure(self, min_pressure: int = 28, max_pressure: int = 31, unit: str = "inHg") -> str:
        """
        Generate a random atmospheric pressure.
        
        :param min_pressure: Minimum pressure (default: 28)
        :param max_pressure: Maximum pressure (default: 31)
        :param unit: Unit 'inHg' or 'mb' (default: 'inHg')
        :example: '29.92 inHg'
        """
        if unit == "inHg":
            pressure = self.random_int(min_pressure * 100, max_pressure * 100) / 100
            return f"{pressure:.2f} {unit}"
        else:  # mb or hPa
            pressure = self.random_int(950, 1050)
            return f"{pressure} {unit}"

    def uv_index(self, min_index: int = 0, max_index: int = 11) -> int:
        """
        Generate a random UV index.
        
        :param min_index: Minimum UV index (default: 0)
        :param max_index: Maximum UV index (default: 11)
        :example: 7
        """
        return self.random_int(min_index, max_index)

    def uv_index_level(self) -> str:
        """
        Generate a random UV index level description.
        
        :example: 'High'
        """
        return self.random_element(self.uv_index_levels)

    def air_quality(self) -> str:
        """
        Generate a random air quality level.
        
        :example: 'Good'
        """
        return self.random_element(self.air_quality_levels)

    def air_quality_index(self, min_aqi: int = 0, max_aqi: int = 300) -> int:
        """
        Generate a random Air Quality Index (AQI).
        
        :param min_aqi: Minimum AQI (default: 0)
        :param max_aqi: Maximum AQI (default: 300)
        :example: 45
        """
        return self.random_int(min_aqi, max_aqi)

    def weather_alert(self) -> str:
        """
        Generate a random weather alert.
        
        :example: 'Severe Thunderstorm Watch'
        """
        return self.random_element(self.weather_alerts)

    def season(self) -> str:
        """
        Generate a random season.
        
        :example: 'Summer'
        """
        return self.random_element(self.seasons)

    def moon_phase(self) -> str:
        """
        Generate a random moon phase.
        
        :example: 'Full Moon'
        """
        return self.random_element(self.moon_phases)

    def sunrise_time(self) -> str:
        """
        Generate a random sunrise time.
        
        :example: '6:45 AM'
        """
        hour = self.random_int(5, 7)
        minute = self.random_int(0, 59)
        return f"{hour}:{minute:02d} AM"

    def sunset_time(self) -> str:
        """
        Generate a random sunset time.
        
        :example: '7:30 PM'
        """
        hour = self.random_int(5, 9)
        minute = self.random_int(0, 59)
        return f"{hour}:{minute:02d} PM"

    def feels_like_temperature(self, min_temp: int = -20, max_temp: int = 110, unit: str = "F") -> str:
        """
        Generate a random 'feels like' temperature.
        
        :param min_temp: Minimum temperature (default: -20)
        :param max_temp: Maximum temperature (default: 110)
        :param unit: Temperature unit 'F' or 'C' (default: 'F')
        :example: '68°F'
        """
        return self.temperature(min_temp, max_temp, unit)

    def dew_point(self, min_temp: int = -20, max_temp: int = 80, unit: str = "F") -> str:
        """
        Generate a random dew point temperature.
        
        :param min_temp: Minimum temperature (default: -20)
        :param max_temp: Maximum temperature (default: 80)
        :param unit: Temperature unit 'F' or 'C' (default: 'F')
        :example: '55°F'
        """
        return self.temperature(min_temp, max_temp, unit)

    def chance_of_rain(self, min_chance: int = 0, max_chance: int = 100) -> str:
        """
        Generate a random chance of rain percentage.
        
        :param min_chance: Minimum chance (default: 0)
        :param max_chance: Maximum chance (default: 100)
        :example: '30%'
        """
        chance = self.random_int(min_chance, max_chance)
        return f"{chance}%"
